Class AppiumExecutionMethod

java.lang.Object
io.appium.java_client.AppiumExecutionMethod
All Implemented Interfaces:
org.openqa.selenium.remote.ExecuteMethod

public class AppiumExecutionMethod extends Object implements org.openqa.selenium.remote.ExecuteMethod
  • Constructor Details

    • AppiumExecutionMethod

      public AppiumExecutionMethod(AppiumDriver driver)
  • Method Details

    • execute

      public @Nullable Object execute(@NonNull String commandName, @Nullable Map<String,?> parameters)
      This method executes a command supported by Appium JSONWP.
      Specified by:
      execute in interface org.openqa.selenium.remote.ExecuteMethod
      Parameters:
      commandName - a JSONWP command
      parameters - is a map which contains parameter names as keys and parameter values
      Returns:
      a command execution result