Class AppiumFluentWait.IterationInfo

java.lang.Object
io.appium.java_client.AppiumFluentWait.IterationInfo
Enclosing class:
AppiumFluentWait<T>

public static class AppiumFluentWait.IterationInfo extends Object
  • Constructor Details

    • IterationInfo

      public IterationInfo(long number, Duration elapsed, Duration total, Duration interval)
      The class is used to represent information about a single loop iteration in AppiumFluentWait.until(Function) method.
      Parameters:
      number - loop iteration number, starts from 1
      elapsed - the amount of elapsed time since the loop started
      total - the amount of total time to run the loop
      interval - the default time interval for each loop iteration