Interface ComparesImages

All Superinterfaces:
ExecutesMethod
All Known Implementing Classes:
AndroidDriver, AppiumDriver, ChromiumDriver, FlutterAndroidDriver, FlutterIOSDriver, GeckoDriver, IOSDriver, Mac2Driver, SafariDriver, WindowsDriver

public interface ComparesImages extends ExecutesMethod
  • Method Details

    • matchImagesFeatures

      default FeaturesMatchingResult matchImagesFeatures(byte[] base64image1, byte[] base64Image2)
      Performs images matching by features with default options. Read https://docs.opencv.org/3.0-beta/doc/py_tutorials/py_feature2d/py_matcher/py_matcher.html for more details on this topic.
      Parameters:
      base64image1 - base64-encoded representation of the first image
      base64Image2 - base64-encoded representation of the second image
      Returns:
      The matching result.
    • matchImagesFeatures

      default FeaturesMatchingResult matchImagesFeatures(byte[] base64image1, byte[] base64Image2, @Nullable FeaturesMatchingOptions options)
      Performs images matching by features. Read https://docs.opencv.org/3.0-beta/doc/py_tutorials/py_feature2d/py_matcher/py_matcher.html for more details on this topic.
      Parameters:
      base64image1 - base64-encoded representation of the first image
      base64Image2 - base64-encoded representation of the second image
      options - comparison options
      Returns:
      The matching result. The configuration of fields in the result depends on comparison options.
    • matchImagesFeatures

      default FeaturesMatchingResult matchImagesFeatures(File image1, File image2) throws IOException
      Performs images matching by features with default options. Read https://docs.opencv.org/3.0-beta/doc/py_tutorials/py_feature2d/py_matcher/py_matcher.html for more details on this topic.
      Parameters:
      image1 - The location of the first image
      image2 - The location of the second image
      Returns:
      The matching result.
      Throws:
      IOException - On file system I/O error.
    • matchImagesFeatures

      default FeaturesMatchingResult matchImagesFeatures(File image1, File image2, @Nullable FeaturesMatchingOptions options) throws IOException
      Performs images matching by features. Read https://docs.opencv.org/3.0-beta/doc/py_tutorials/py_feature2d/py_matcher/py_matcher.html for more details on this topic.
      Parameters:
      image1 - The location of the first image
      image2 - The location of the second image
      options - comparison options
      Returns:
      The matching result. The configuration of fields in the result depends on comparison options.
      Throws:
      IOException - On file system I/O error.
    • findImageOccurrence

      default OccurrenceMatchingResult findImageOccurrence(byte[] fullImage, byte[] partialImage)
      Performs images matching by template to find possible occurrence of the partial image in the full image with default options. Read https://docs.opencv.org/2.4/doc/tutorials/imgproc/histograms/template_matching/template_matching.html for more details on this topic.
      Parameters:
      fullImage - base64-encoded representation of the full image
      partialImage - base64-encoded representation of the partial image
      Returns:
      The matching result.
    • findImageOccurrence

      default OccurrenceMatchingResult findImageOccurrence(byte[] fullImage, byte[] partialImage, @Nullable OccurrenceMatchingOptions options)
      Performs images matching by template to find possible occurrence of the partial image in the full image. Read https://docs.opencv.org/2.4/doc/tutorials/imgproc/histograms/template_matching/template_matching.html for more details on this topic.
      Parameters:
      fullImage - base64-encoded representation of the full image
      partialImage - base64-encoded representation of the partial image
      options - comparison options
      Returns:
      The matching result. The configuration of fields in the result depends on comparison options.
    • findImageOccurrence

      default OccurrenceMatchingResult findImageOccurrence(File fullImage, File partialImage) throws IOException
      Performs images matching by template to find possible occurrence of the partial image in the full image with default options. Read https://docs.opencv.org/2.4/doc/tutorials/imgproc/histograms/template_matching/template_matching.html for more details on this topic.
      Parameters:
      fullImage - The location of the full image
      partialImage - The location of the partial image
      Returns:
      The matching result. The configuration of fields in the result depends on comparison options.
      Throws:
      IOException - On file system I/O error.
    • findImageOccurrence

      default OccurrenceMatchingResult findImageOccurrence(File fullImage, File partialImage, @Nullable OccurrenceMatchingOptions options) throws IOException
      Performs images matching by template to find possible occurrence of the partial image in the full image. Read https://docs.opencv.org/2.4/doc/tutorials/imgproc/histograms/template_matching/template_matching.html for more details on this topic.
      Parameters:
      fullImage - The location of the full image
      partialImage - The location of the partial image
      options - comparison options
      Returns:
      The matching result. The configuration of fields in the result depends on comparison options.
      Throws:
      IOException - On file system I/O error.
    • getImagesSimilarity

      default SimilarityMatchingResult getImagesSimilarity(byte[] base64image1, byte[] base64Image2)
      Performs images matching to calculate the similarity score between them with default options. The flow there is similar to the one used in findImageOccurrence(byte[], byte[], OccurrenceMatchingOptions), but it is mandatory that both images are of equal size.
      Parameters:
      base64image1 - base64-encoded representation of the first image
      base64Image2 - base64-encoded representation of the second image
      Returns:
      Matching result. The configuration of fields in the result depends on comparison options.
    • getImagesSimilarity

      default SimilarityMatchingResult getImagesSimilarity(byte[] base64image1, byte[] base64Image2, @Nullable SimilarityMatchingOptions options)
      Performs images matching to calculate the similarity score between them. The flow there is similar to the one used in findImageOccurrence(byte[], byte[], OccurrenceMatchingOptions), but it is mandatory that both images are of equal size.
      Parameters:
      base64image1 - base64-encoded representation of the first image
      base64Image2 - base64-encoded representation of the second image
      options - comparison options
      Returns:
      Matching result. The configuration of fields in the result depends on comparison options.
    • getImagesSimilarity

      default SimilarityMatchingResult getImagesSimilarity(File image1, File image2) throws IOException
      Performs images matching to calculate the similarity score between them with default options. The flow there is similar to the one used in findImageOccurrence(byte[], byte[], OccurrenceMatchingOptions), but it is mandatory that both images are of equal size.
      Parameters:
      image1 - The location of the full image
      image2 - The location of the partial image
      Returns:
      Matching result. The configuration of fields in the result depends on comparison options.
      Throws:
      IOException - On file system I/O error.
    • getImagesSimilarity

      default SimilarityMatchingResult getImagesSimilarity(File image1, File image2, @Nullable SimilarityMatchingOptions options) throws IOException
      Performs images matching to calculate the similarity score between them. The flow there is similar to the one used in findImageOccurrence(byte[], byte[], OccurrenceMatchingOptions), but it is mandatory that both images are of equal size.
      Parameters:
      image1 - The location of the full image
      image2 - The location of the partial image
      options - comparison options
      Returns:
      Matching result. The configuration of fields in the result depends on comparison options.
      Throws:
      IOException - On file system I/O error.