Interface ExecutesDriverScript

All Superinterfaces:
ExecutesMethod
All Known Implementing Classes:
AndroidDriver, AppiumDriver, ChromiumDriver, FlutterAndroidDriver, FlutterIOSDriver, GeckoDriver, IOSDriver, Mac2Driver, SafariDriver, WindowsDriver

public interface ExecutesDriverScript extends ExecutesMethod
  • Method Details

    • executeDriverScript

      default ScriptValue executeDriverScript(String script, @Nullable ScriptOptions options)
      Run a set of scripts in scope of the current session. This allows multiple web driver commands to be executed within one request and may significantly speed up the automation script performance in distributed client-server environments with high latency. Read http://appium.io/docs/en/commands/session/execute-driver for more details.
      Parameters:
      script - the web driver script to execute (it should be a valid webdriverio code snippet by default unless another option is provided)
      options - additional scripting options
      Returns:
      The script result
      Throws:
      org.openqa.selenium.WebDriverException - if there was a failure while executing the script
      Since:
      Appium 1.14
    • executeDriverScript

      default ScriptValue executeDriverScript(String script)
      Run a set of scripts in scope of the current session with default options.
      Parameters:
      script - the web driver script to execute (it should be a valid webdriverio code snippet)
      Returns:
      The script result
      Since:
      Appium 1.14