Interface HasAppStrings

All Superinterfaces:
CanRememberExtensionPresence, ExecutesMethod
All Known Implementing Classes:
AndroidDriver, FlutterAndroidDriver, FlutterIOSDriver, IOSDriver

public interface HasAppStrings extends ExecutesMethod, CanRememberExtensionPresence
  • Method Details

    • getAppStringMap

      default Map<String,String> getAppStringMap()
      Get all defined Strings from an app for the default language. See the documentation for 'mobile: getAppStrings' extension for more details.
      Returns:
      a map with localized strings defined in the app
    • getAppStringMap

      default Map<String,String> getAppStringMap(String language)
      Get all defined Strings from an app for the specified language. See the documentation for 'mobile: getAppStrings' extension for more details.
      Parameters:
      language - strings language code
      Returns:
      a map with localized strings defined in the app
    • getAppStringMap

      default Map<String,String> getAppStringMap(String language, String stringFile)
      Get all defined Strings from an app for the specified language and strings filename. See the documentation for 'mobile: getAppStrings' extension for more details.
      Parameters:
      language - strings language code
      stringFile - strings filename. Ignored on Android
      Returns:
      a map with localized strings defined in the app