Interface HasBrowserCheck

All Superinterfaces:
ExecutesMethod, org.openqa.selenium.HasCapabilities
All Known Implementing Classes:
AndroidDriver, AppiumDriver, ChromiumDriver, FlutterAndroidDriver, FlutterIOSDriver, GeckoDriver, IOSDriver, Mac2Driver, SafariDriver, WindowsDriver

public interface HasBrowserCheck extends ExecutesMethod, org.openqa.selenium.HasCapabilities
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
  • Method Summary

    Modifier and Type
    Method
    Description
    default boolean
    Validates if the driver is currently in a web browser context.

    Methods inherited from interface io.appium.java_client.ExecutesMethod

    execute, execute

    Methods inherited from interface org.openqa.selenium.HasCapabilities

    getCapabilities
  • Field Details

  • Method Details

    • isBrowser

      default boolean isBrowser()
      Validates if the driver is currently in a web browser context.
      Returns:
      true or false.