Interface HasSettings

All Superinterfaces:
ExecutesMethod
All Known Subinterfaces:
HasAndroidSettings, HasIOSSettings
All Known Implementing Classes:
AndroidDriver, AppiumDriver, ChromiumDriver, FlutterAndroidDriver, FlutterIOSDriver, GeckoDriver, IOSDriver, Mac2Driver, SafariDriver, WindowsDriver

public interface HasSettings extends ExecutesMethod
  • Method Details

    • setSetting

      default HasSettings setSetting(Setting setting, Object value)
      Set a setting for this test session It's probably better to use a convenience function, rather than use this function directly. Try finding the method for the specific setting you want to change.
      Parameters:
      setting - Setting you wish to set.
      value - Value of the setting.
      Returns:
      Self instance for chaining.
    • setSetting

      default HasSettings setSetting(String settingName, Object value)
      Set a setting for this test session It's probably better to use a convenience function, rather than use this function directly. Try finding the method for the specific setting you want to change.
      Parameters:
      settingName - Setting name you wish to set.
      value - Value of the setting.
      Returns:
      Self instance for chaining.
    • setSettings

      default HasSettings setSettings(EnumMap<Setting,Object> settings)
      Sets settings for this test session.
      Parameters:
      settings - a map with settings, where key is the setting name you wish to set and value is the value of the setting.
      Returns:
      Self instance for chaining.
    • setSettings

      default HasSettings setSettings(Map<String,Object> settings)
      Sets settings for this test session.
      Parameters:
      settings - a map with settings, where key is the setting name you wish to set and value is the value of the setting.
      Returns:
      Self instance for chaining.
    • getSettings

      default Map<String,Object> getSettings()
      Get settings stored for this test session It's probably better to use a convenience function, rather than use this function directly. Try finding the method for the specific setting you want to read.
      Returns:
      JsonObject, a straight-up hash of settings.