Package io.appium.java_client
Interface LogsEvents
- All Superinterfaces:
ExecutesMethod
- All Known Implementing Classes:
AndroidDriver,AppiumDriver,ChromiumDriver,FlutterAndroidDriver,FlutterIOSDriver,GeckoDriver,IOSDriver,Mac2Driver,SafariDriver,WindowsDriver
-
Method Summary
Modifier and TypeMethodDescriptiondefault ServerEventsLog a custom event on the Appium server.default voidlogEvent(CustomEvent event) Log a custom event on the Appium server.Methods inherited from interface io.appium.java_client.ExecutesMethod
execute, execute
-
Method Details
-
logEvent
Log a custom event on the Appium server.- Parameters:
event- the event to log- Throws:
org.openqa.selenium.WebDriverException- if there was a failure while executing the script- Since:
- Appium 1.16
-
getEvents
Log a custom event on the Appium server.- Returns:
- ServerEvents object wrapping up the various command and event timestamps
- Throws:
org.openqa.selenium.WebDriverException- if there was a failure while executing the script- Since:
- Appium 1.16
-