Interface PushesFiles

All Superinterfaces:
CanRememberExtensionPresence, ExecutesMethod
All Known Implementing Classes:
AndroidDriver, FlutterAndroidDriver, FlutterIOSDriver, IOSDriver, WindowsDriver

public interface PushesFiles extends ExecutesMethod, CanRememberExtensionPresence
  • Method Details

    • pushFile

      default void pushFile(String remotePath, byte[] base64Data)
      Saves base64-encoded data as a file on the remote system.
      Parameters:
      remotePath - Path to file to write data to on remote device. Check the documentation on `mobile: pushFile` extension for more details on possible values for different platforms.
      base64Data - Base64 encoded byte array of media file data to write to remote device
    • pushFile

      default void pushFile(String remotePath, File file) throws IOException
      Sends the file to the remote device.
      Parameters:
      remotePath - See the documentation on pushFile(String, byte[])
      file - Is an existing local file to be written to the remote device
      Throws:
      IOException - when there are problems with a file on current file system