Interface HasAndroidDeviceDetails

All Superinterfaces:
CanRememberExtensionPresence, ExecutesMethod
All Known Implementing Classes:
AndroidDriver, FlutterAndroidDriver

public interface HasAndroidDeviceDetails extends ExecutesMethod, CanRememberExtensionPresence
  • Method Details

    • getDisplayDensity

      default Long getDisplayDensity()
      Retrieve the display density of the Android device.
      Returns:
      The density value in dpi
    • getSystemBars

      default Map<String,Map<String,Object>> getSystemBars()
      Retrieve visibility and bounds information of the status and navigation bars.
      Returns:
      The map where keys are bar types and values are mappings of bar properties.