Package io.appium.java_client.android
Interface StartsActivity
- All Superinterfaces:
CanRememberExtensionPresence,ExecutesMethod
- All Known Implementing Classes:
AndroidDriver,FlutterAndroidDriver
-
Method Summary
Methods inherited from interface io.appium.java_client.CanRememberExtensionPresence
assertExtensionExists, markExtensionAbsenceMethods inherited from interface io.appium.java_client.ExecutesMethod
execute, execute
-
Method Details
-
currentActivity
Get the current activity being run on the mobile device.- Returns:
- a current activity being run on the mobile device.
-
getCurrentPackage
Get the current package being run on the mobile device.- Returns:
- a current package being run on the mobile device.
-