Class AndroidInstallApplicationOptions


public class AndroidInstallApplicationOptions extends BaseInstallApplicationOptions<AndroidInstallApplicationOptions>
  • Constructor Details

    • AndroidInstallApplicationOptions

      public AndroidInstallApplicationOptions()
  • Method Details

    • withReplaceEnabled

      public AndroidInstallApplicationOptions withReplaceEnabled()
      Enables the possibility to upgrade/reinstall the application if it is already present on the device (the default behavior).
      Returns:
      self instance for chaining.
    • withReplaceDisabled

      public AndroidInstallApplicationOptions withReplaceDisabled()
      Disables the possibility to upgrade/reinstall the application if it is already present on the device.
      Returns:
      self instance for chaining.
    • withTimeout

      public AndroidInstallApplicationOptions withTimeout(Duration timeout)
      The time to wait until the app is installed (60000ms by default).
      Parameters:
      timeout - the actual timeout value. The minimum time resolution unit is one millisecond.
      Returns:
      self instance for chaining.
    • withAllowTestPackagesEnabled

      public AndroidInstallApplicationOptions withAllowTestPackagesEnabled()
      Allows to install packages marked as test in the manifest.
      Returns:
      self instance for chaining.
    • withAllowTestPackagesDisabled

      public AndroidInstallApplicationOptions withAllowTestPackagesDisabled()
      Disables a possibility to install packages marked as test in the manifest (the default setting).
      Returns:
      self instance for chaining.
    • withUseSdcardEnabled

      public AndroidInstallApplicationOptions withUseSdcardEnabled()
      Forces the application to be installed of SD card instead of the internal memory.
      Returns:
      self instance for chaining.
    • withUseSdcardDisabled

      public AndroidInstallApplicationOptions withUseSdcardDisabled()
      Forces the application to be installed to the internal memory (the default behavior).
      Returns:
      self instance for chaining.
    • withGrantPermissionsEnabled

      public AndroidInstallApplicationOptions withGrantPermissionsEnabled()
      Grants all the permissions requested in the application's manifest automatically after the installation is completed under Android 6+.
      Returns:
      self instance for chaining.
    • withGrantPermissionsDisabled

      public AndroidInstallApplicationOptions withGrantPermissionsDisabled()
      Does not grant all the permissions requested in the application's manifest automatically after the installation is completed (the default behavior).
      Returns:
      self instance for chaining.
    • build

      public Map<String,Object> build()
      Description copied from class: BaseOptions
      Creates a map based on the provided options.
      Specified by:
      build in class BaseOptions<AndroidInstallApplicationOptions>
      Returns:
      options mapping.