Class AndroidRemoveApplicationOptions
java.lang.Object
io.appium.java_client.appmanagement.BaseOptions<T>
io.appium.java_client.appmanagement.BaseRemoveApplicationOptions<AndroidRemoveApplicationOptions>
io.appium.java_client.android.appmanagement.AndroidRemoveApplicationOptions
public class AndroidRemoveApplicationOptions
extends BaseRemoveApplicationOptions<AndroidRemoveApplicationOptions>
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Creates a map based on the provided options.Forces uninstall to delete the application data and caches (the default behavior).Forces uninstall to keep the application data and caches.withTimeout(Duration timeout) The time to wait until the app is removed (20000ms by default).
-
Constructor Details
-
AndroidRemoveApplicationOptions
public AndroidRemoveApplicationOptions()
-
-
Method Details
-
withTimeout
The time to wait until the app is removed (20000ms by default).- Parameters:
timeout- the actual timeout value. The minimum time resolution unit is one millisecond.- Returns:
- self instance for chaining.
-
withKeepDataEnabled
Forces uninstall to keep the application data and caches.- Returns:
- self instance for chaining.
-
withKeepDataDisabled
Forces uninstall to delete the application data and caches (the default behavior).- Returns:
- self instance for chaining.
-
build
Description copied from class:BaseOptionsCreates a map based on the provided options.- Specified by:
buildin classBaseOptions<AndroidRemoveApplicationOptions>- Returns:
- options mapping.
-