-
Method Summary
default void
Send a long press key event to the device under test.
default void
Send a key event to the device under test.
-
Method Details
-
pressKey
default void pressKey(KeyEvent keyEvent)
Send a key event to the device under test.
- Parameters:
keyEvent - The generated native key event
-
longPressKey
default void longPressKey(KeyEvent keyEvent)
Send a long press key event to the device under test.
- Parameters:
keyEvent - The generated native key event