Class ActivityOptions
java.lang.Object
io.appium.java_client.remote.options.BaseMapOptionData<ActivityOptions>
io.appium.java_client.android.options.app.ActivityOptions
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionGet display id which you want to assign to launch the main app activity on.withLaunchDisplayId(int id) Display id which you want to assign to launch the main app activity on.Methods inherited from class io.appium.java_client.remote.options.BaseMapOptionData
assignOptionValue, getOptionValue, toJson, toMap, toString
-
Constructor Details
-
ActivityOptions
public ActivityOptions() -
ActivityOptions
-
-
Method Details
-
withLaunchDisplayId
Display id which you want to assign to launch the main app activity on. This might be useful if the device under test supports multiple displays.- Parameters:
id- Display identifier.- Returns:
- self instance for chaining.
-
getLaunchDisplayId
Get display id which you want to assign to launch the main app activity on.- Returns:
- Display identifier.
-