Class IntentOptions

java.lang.Object
io.appium.java_client.remote.options.BaseMapOptionData<IntentOptions>
io.appium.java_client.android.options.app.IntentOptions

public class IntentOptions extends BaseMapOptionData<IntentOptions>
  • Constructor Details

    • IntentOptions

      public IntentOptions()
    • IntentOptions

      public IntentOptions(Map<String,Object> options)
  • Method Details

    • withAction

      public IntentOptions withAction(String action)
      An intent action name. Application-specific actions should be prefixed with the vendor's package name.
      Parameters:
      action - E.g. ACTION_MAIN.
      Returns:
      self instance for chaining.
    • getAction

      public Optional<String> getAction()
      Get the action name.
      Returns:
      Action name.
    • withData

      public IntentOptions withData(String data)
      Set an intent data URI.
      Parameters:
      data - E.g. content://contacts/people/1.
      Returns:
      self instance for chaining.
    • getData

      public Optional<String> getData()
      Get intent data URI.
      Returns:
      Intent data URI.
    • withType

      public IntentOptions withType(String type)
      Intent MIME type.
      Parameters:
      type - E.g. image/png.
      Returns:
      self instance for chaining.
    • getType

      public Optional<String> getType()
      Get an intent type.
      Returns:
      Intent type.
    • withCategories

      public IntentOptions withCategories(String categories)
      Set intent categories.
      Parameters:
      categories - One or more comma-separated Intent categories.
      Returns:
      self instance for chaining.
    • getCategories

      public Optional<String> getCategories()
      Get intent categories.
      Returns:
      Intent categories.
    • withComponent

      public IntentOptions withComponent(String component)
      Set intent component name with package name prefix to create an explicit intent.
      Parameters:
      component - E.g. com.example.app/.ExampleActivity.
      Returns:
      self instance for chaining.
    • getComponent

      public Optional<String> getComponent()
      Get intent component name.
      Returns:
      Intent component name.
    • withIntFlags

      public IntentOptions withIntFlags(String intFlags)
      Single-string value, which represents intent flags set encoded into an integer. Could also be provided in hexadecimal format. Check https://developer.android.com/reference/android/content/Intent.html#setFlags(int) for more details.
      Parameters:
      intFlags - E.g. 0x0F.
      Returns:
      self instance for chaining.
    • getIntFlags

      public Optional<String> getIntFlags()
      Get intent flags.
      Returns:
      Intent flags encoded into a hexadecimal value.
    • withFlags

      public IntentOptions withFlags(String flags)
      Comma-separated string of intent flag names.
      Parameters:
      flags - E.g. 'ACTIVITY_CLEAR_TASK' (the 'FLAG_' prefix is optional).
      Returns:
      self instance for chaining.
    • getFlags

      public Optional<String> getFlags()
      Get intent flag names.
      Returns:
      Comma-separated string of intent flag names.
    • withClassName

      public IntentOptions withClassName(String className)
      The name of a class inside of the application package that will be used as the component for this Intent.
      Parameters:
      className - E.g. com.example.app.MainActivity.
      Returns:
      self instance for chaining.
    • getClassName

      public Optional<String> getClassName()
      Get class name.
      Returns:
      Class name.
    • withEs

      public IntentOptions withEs(Map<String,String> es)
      Intent string parameters.
      Parameters:
      es - Map, where the key is arg parameter name and value is its string value.
      Returns:
      self instance for chaining.
    • getEs

      public Optional<Map<String,String>> getEs()
      Get intent string parameters.
      Returns:
      Intent string parameters mapping.
    • withEsn

      public IntentOptions withEsn(List<String> esn)
      Intent null parameters.
      Parameters:
      esn - List, where keys are parameter names.
      Returns:
      self instance for chaining.
    • getEsn

      public Optional<List<String>> getEsn()
      Get intent null parameters.
      Returns:
      Intent null parameters.
    • withEz

      public IntentOptions withEz(Map<String,Boolean> ez)
      Intent boolean parameters.
      Parameters:
      ez - Map, where keys are parameter names and values are booleans.
      Returns:
      self instance for chaining.
    • getEz

      public Optional<Map<String,Boolean>> getEz()
      Get intent boolean parameters.
      Returns:
      Intent boolean parameters.
    • withEi

      public IntentOptions withEi(Map<String,Integer> ei)
      Intent integer parameters.
      Parameters:
      ei - Map, where keys are parameter names and values are integers.
      Returns:
      self instance for chaining.
    • getEi

      public Optional<Map<String,Integer>> getEi()
      Get intent integer parameters.
      Returns:
      Intent integer parameters.
    • withEl

      public IntentOptions withEl(Map<String,Long> el)
      Intent long parameters.
      Parameters:
      el - Map, where keys are parameter names and values are long numbers.
      Returns:
      self instance for chaining.
    • getEl

      public Optional<Map<String,Long>> getEl()
      Get intent long parameters.
      Returns:
      Intent long parameters.
    • withEf

      public IntentOptions withEf(Map<String,Float> ef)
      Intent float parameters.
      Parameters:
      ef - Map, where keys are parameter names and values are float numbers.
      Returns:
      self instance for chaining.
    • getEf

      public Optional<Map<String,Float>> getEf()
      Get intent float parameters.
      Returns:
      Intent float parameters.
    • withEu

      public IntentOptions withEu(Map<String,String> eu)
      Intent URI-data parameters.
      Parameters:
      eu - Map, where keys are parameter names and values are valid URIs.
      Returns:
      self instance for chaining.
    • getEu

      public Optional<Map<String,String>> getEu()
      Get intent URI parameters.
      Returns:
      Intent URI parameters.
    • withEcn

      public IntentOptions withEcn(Map<String,String> ecn)
      Intent component name parameters.
      Parameters:
      ecn - Map, where keys are parameter names and values are valid component names.
      Returns:
      self instance for chaining.
    • getEcn

      public Optional<Map<String,String>> getEcn()
      Get intent component name parameters.
      Returns:
      Intent component name parameters.
    • withEia

      public IntentOptions withEia(Map<String,List<Integer>> eia)
      Intent integer array parameters.
      Parameters:
      eia - Map, where keys are parameter names and values are lists of integers.
      Returns:
      self instance for chaining.
    • getEia

      public Optional<Map<String,String>> getEia()
      Get intent integer array parameters.
      Returns:
      Intent integer array parameters.
    • withEla

      public IntentOptions withEla(Map<String,List<Long>> ela)
      Intent long array parameters.
      Parameters:
      ela - Map, where keys are parameter names and values are lists of long numbers.
      Returns:
      self instance for chaining.
    • getEla

      public Optional<Map<String,String>> getEla()
      Get intent long array parameters.
      Returns:
      Intent long array parameters.
    • withEfa

      public IntentOptions withEfa(Map<String,List<Float>> efa)
      Intent float array parameters.
      Parameters:
      efa - Map, where keys are parameter names and values are lists of float numbers.
      Returns:
      self instance for chaining.
    • getEfa

      public Optional<Map<String,String>> getEfa()
      Get intent float array parameters.
      Returns:
      Intent float array parameters.