Interface SupportsAndroidInstallTimeoutOption<T extends BaseOptions<T>>

All Superinterfaces:
CanSetCapability<T>, org.openqa.selenium.Capabilities, Serializable
All Known Implementing Classes:
EspressoOptions, UiAutomator2Options

public interface SupportsAndroidInstallTimeoutOption<T extends BaseOptions<T>> extends org.openqa.selenium.Capabilities, CanSetCapability<T>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
  • Method Summary

    Modifier and Type
    Method
    Description
    Get maximum amount of time to wait until the application under test is installed.
    default T
    Maximum amount of time to wait until the application under test is installed.

    Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability

    amend, setCapability

    Methods inherited from interface org.openqa.selenium.Capabilities

    asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
  • Field Details

  • Method Details

    • setAndroidInstallTimeout

      default T setAndroidInstallTimeout(Duration installTimeout)
      Maximum amount of time to wait until the application under test is installed. 90000 ms by default
      Parameters:
      installTimeout - App install timeout.
      Returns:
      self instance for chaining.
    • getAndroidInstallTimeout

      default Optional<Duration> getAndroidInstallTimeout()
      Get maximum amount of time to wait until the application under test is installed.
      Returns:
      Timeout value.