Interface SupportsAutoWebviewTimeoutOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
EspressoOptions,UiAutomator2Options
public interface SupportsAutoWebviewTimeoutOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionGet the timeout to wait until a web view is available.default TsetAutoWebviewTimeout(Duration timeout) Set the maximum timeout to wait until a web view is available if autoWebview capability is set to true.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
AUTO_WEBVIEW_TIMEOUT_OPTION
- See Also:
-
-
Method Details
-
setAutoWebviewTimeout
Set the maximum timeout to wait until a web view is available if autoWebview capability is set to true. 2000 ms by default.- Parameters:
timeout- Timeout value.- Returns:
- self instance for chaining.
-
getAutoWebviewTimeout
Get the timeout to wait until a web view is available.- Returns:
- The timeout value.
-