Interface SupportsLocaleScriptOption<T extends BaseOptions<T>>

All Superinterfaces:
CanSetCapability<T>, org.openqa.selenium.Capabilities, Serializable
All Known Implementing Classes:
EspressoOptions, UiAutomator2Options

public interface SupportsLocaleScriptOption<T extends BaseOptions<T>> extends org.openqa.selenium.Capabilities, CanSetCapability<T>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
  • Method Summary

    Modifier and Type
    Method
    Description
    default Optional<String>
    Get canonical name of the locale to be set for the app under test.
    default T
    setLocaleScript(String localeScript)
    Set canonical name of the locale to be set for the app under test, for example zh-Hans-CN.

    Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability

    amend, setCapability

    Methods inherited from interface org.openqa.selenium.Capabilities

    asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
  • Field Details

  • Method Details

    • setLocaleScript

      default T setLocaleScript(String localeScript)
      Set canonical name of the locale to be set for the app under test, for example zh-Hans-CN. See https://developer.android.com/reference/java/util/Locale.html for more details.
      Parameters:
      localeScript - is the language abbreviation.
      Returns:
      this MobileOptions, for chaining.
    • getLocaleScript

      default Optional<String> getLocaleScript()
      Get canonical name of the locale to be set for the app under test.
      Returns:
      Locale script value.