Interface SupportsDisableWindowAnimationOption<T extends BaseOptions<T>>

All Superinterfaces:
CanSetCapability<T>, org.openqa.selenium.Capabilities, Serializable
All Known Implementing Classes:
UiAutomator2Options

public interface SupportsDisableWindowAnimationOption<T extends BaseOptions<T>> extends org.openqa.selenium.Capabilities, CanSetCapability<T>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
  • Method Summary

    Modifier and Type
    Method
    Description
    default T
    Disables window animations when starting the instrumentation process.
    default Optional<Boolean>
    Get whether window animations when starting the instrumentation process are disabled.
    default T
    Set whether to disable window animations when starting the instrumentation process.

    Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability

    amend, setCapability

    Methods inherited from interface org.openqa.selenium.Capabilities

    asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
  • Field Details

  • Method Details

    • disableWindowAnimation

      default T disableWindowAnimation()
      Disables window animations when starting the instrumentation process.
      Returns:
      self instance for chaining.
    • setDisableWindowAnimation

      default T setDisableWindowAnimation(boolean value)
      Set whether to disable window animations when starting the instrumentation process. false by default
      Parameters:
      value - True to disable window animations.
      Returns:
      self instance for chaining.
    • doesDisableWindowAnimation

      default Optional<Boolean> doesDisableWindowAnimation()
      Get whether window animations when starting the instrumentation process are disabled.
      Returns:
      True or false.