Interface SupportsUseSystemExecutableOption<T extends BaseOptions<T>>

All Superinterfaces:
CanSetCapability<T>, org.openqa.selenium.Capabilities, Serializable
All Known Implementing Classes:
ChromiumOptions

public interface SupportsUseSystemExecutableOption<T extends BaseOptions<T>> extends org.openqa.selenium.Capabilities, CanSetCapability<T>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
  • Method Summary

    Modifier and Type
    Method
    Description
    default Optional<Boolean>
    Get the use system executable flag.
    default T
    setUseSystemExecutable(boolean useSystemExecutable)
    Set to true to use the version of WebDriver bundled with this driver, rather than attempting to download a new one based on the version of the browser under test.

    Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability

    amend, setCapability

    Methods inherited from interface org.openqa.selenium.Capabilities

    asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
  • Field Details

  • Method Details

    • setUseSystemExecutable

      default T setUseSystemExecutable(boolean useSystemExecutable)
      Set to true to use the version of WebDriver bundled with this driver, rather than attempting to download a new one based on the version of the browser under test. Unless disable build check preference has been user-set, the capability is not present because the default value is false.
      Parameters:
      useSystemExecutable - flag.
      Returns:
      self instance for chaining.
    • isUseSystemExecutable

      default Optional<Boolean> isUseSystemExecutable()
      Get the use system executable flag.
      Returns:
      use system executable flag.