Class ScriptOptions
java.lang.Object
io.appium.java_client.driverscripts.ScriptOptions
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a values map for further usage in HTTP requests to Appium.withScriptType(ScriptType type) Sets the script type.withTimeout(long timeoutMs) Sets the script execution timeout.
-
Constructor Details
-
ScriptOptions
public ScriptOptions()
-
-
Method Details
-
withScriptType
Sets the script type.- Parameters:
type- the actual script type- Returns:
- self instance for chaining
-
withTimeout
Sets the script execution timeout. If this is not set then the maximum duration of the script is not limited (e. g. may block forever).- Parameters:
timeoutMs- the timeout in milliseconds- Returns:
- self instance for chaining
-
build
Builds a values map for further usage in HTTP requests to Appium.- Returns:
- The map containing the provided options
-