Interface FlutterIntegrationTestDriver

All Superinterfaces:
CanExecuteFlutterScripts, org.openqa.selenium.JavascriptExecutor, org.openqa.selenium.SearchContext, SupportsFlutterCameraMocking, SupportsGestureOnFlutterElements, SupportsScrollingOfFlutterElements, SupportsWaitingForFlutterElements, org.openqa.selenium.WebDriver
All Known Implementing Classes:
FlutterAndroidDriver, FlutterIOSDriver

public interface FlutterIntegrationTestDriver extends org.openqa.selenium.WebDriver, SupportsGestureOnFlutterElements, SupportsScrollingOfFlutterElements, SupportsWaitingForFlutterElements, SupportsFlutterCameraMocking
The FlutterDriver interface represents a driver that controls interactions with Flutter applications, extending WebDriver and providing additional capabilities for interacting with Flutter-specific elements and behaviors.

This interface serves as a common entity for drivers that support Flutter applications on different platforms, such as Android and iOS.

See Also: