Class FlutterCommandParameter
java.lang.Object
io.appium.java_client.flutter.commands.FlutterCommandParameter
- Direct Known Subclasses:
DoubleClickParameter,DragAndDropParameter,LongPressParameter,ScrollParameter,WaitParameter
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionParses an Appium Flutter locator into a Map representation suitable for Flutter Integration Driver.toJson()
-
Constructor Details
-
FlutterCommandParameter
public FlutterCommandParameter()
-
-
Method Details
-
parseFlutterLocator
Parses an Appium Flutter locator into a Map representation suitable for Flutter Integration Driver.- Parameters:
by- The FlutterBy instance representing the locator to parse.- Returns:
- A Map containing the parsed locator information with keys using and value.
-
toJson
-