Class ScrollParameter

java.lang.Object
io.appium.java_client.flutter.commands.FlutterCommandParameter
io.appium.java_client.flutter.commands.ScrollParameter

public class ScrollParameter extends FlutterCommandParameter
  • Constructor Details

    • ScrollParameter

      public ScrollParameter(AppiumBy.FlutterBy scrollTo)
      Constructs a new ScrollOptions object with the given parameters.
      Parameters:
      scrollTo - the locator used for scrolling to a specific element
    • ScrollParameter

      public ScrollParameter(AppiumBy.FlutterBy scrollTo, ScrollParameter.ScrollDirection scrollDirection)
      Constructs a new ScrollOptions object with the given parameters.
      Parameters:
      scrollTo - the locator used for scrolling to a specific element
      scrollDirection - the direction in which to scroll (e.g., ScrollDirection.DOWN)
      Throws:
      IllegalArgumentException - if scrollTo is null
  • Method Details