Interface SupportsFlutterElementWaitTimeoutOption<T extends BaseOptions<T>>

All Superinterfaces:
CanSetCapability<T>, org.openqa.selenium.Capabilities, Serializable
All Known Implementing Classes:
FlutterDriverOptions

public interface SupportsFlutterElementWaitTimeoutOption<T extends BaseOptions<T>> extends org.openqa.selenium.Capabilities, CanSetCapability<T>
  • Field Details

  • Method Details

    • setFlutterElementWaitTimeout

      default T setFlutterElementWaitTimeout(Duration timeout)
      Sets the Flutter element wait timeout. Defaults to 5 seconds.
      Parameters:
      timeout - The duration to wait for Flutter elements during findElement method
      Returns:
      self instance for chaining.
    • getFlutterElementWaitTimeout

      default Optional<Duration> getFlutterElementWaitTimeout()
      Retrieves the current Flutter element wait timeout if set.
      Returns:
      An Optional containing the duration of the Flutter element wait timeout, or empty if not set.