Class BaseComparisonOptions<T extends BaseComparisonOptions<T>>
java.lang.Object
io.appium.java_client.imagecomparison.BaseComparisonOptions<T>
- Direct Known Subclasses:
FeaturesMatchingOptions,OccurrenceMatchingOptions,SimilarityMatchingOptions
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
BaseComparisonOptions
public BaseComparisonOptions()
-
-
Method Details
-
withEnabledVisualization
Makes the endpoint to return an image, which contains the visualized result of the corresponding picture matching operation. This option is disabled by default.- Returns:
- self instance for chaining
-
build
Builds a map, which is ready to be passed to the subordinated Appium API.- Returns:
- comparison options mapping.
-