Class FeaturesMatchingOptions

java.lang.Object
io.appium.java_client.imagecomparison.BaseComparisonOptions<FeaturesMatchingOptions>
io.appium.java_client.imagecomparison.FeaturesMatchingOptions

public class FeaturesMatchingOptions extends BaseComparisonOptions<FeaturesMatchingOptions>
  • Constructor Details

    • FeaturesMatchingOptions

      public FeaturesMatchingOptions()
  • Method Details

    • withDetectorName

      public FeaturesMatchingOptions withDetectorName(FeatureDetector name)
      Sets the detector name for features matching algorithm. Some of these detectors (FAST, AGAST, GFTT, FAST, SIFT and MSER) are not available in the default OpenCV installation and have to be enabled manually before library compilation. The default detector name is 'ORB'.
      Parameters:
      name - the detector name for features matching.
      Returns:
      self instance for chaining.
    • withMatchFunc

      public FeaturesMatchingOptions withMatchFunc(MatchingFunction name)
      Sets the name of the matching function. The default one is 'BruteForce'.
      Parameters:
      name - the name of the matching function.
      Returns:
      self instance for chaining.
    • withGoodMatchesFactor

      public FeaturesMatchingOptions withGoodMatchesFactor(int factor)
      Sets the maximum count of "good" matches (e. g. with minimal distances).
      Parameters:
      factor - the "good" matches factor
      Returns:
      self instance for chaining.
    • build

      public Map<String,Object> build()
      Description copied from class: BaseComparisonOptions
      Builds a map, which is ready to be passed to the subordinated Appium API.
      Overrides:
      build in class BaseComparisonOptions<FeaturesMatchingOptions>
      Returns:
      comparison options mapping.