Class FeaturesMatchingResult

java.lang.Object
io.appium.java_client.imagecomparison.ComparisonResult
io.appium.java_client.imagecomparison.FeaturesMatchingResult

public class FeaturesMatchingResult extends ComparisonResult
  • Constructor Details

    • FeaturesMatchingResult

      public FeaturesMatchingResult(Map<String,Object> input)
  • Method Details

    • getCount

      public int getCount()
      Returns a count of matched edges on both images.
      Returns:
      The count of matched edges on both images. The more matching edges there are no both images the more similar they are.
    • getTotalCount

      public int getTotalCount()
      Returns a count of matched edges on both images.
      Returns:
      The total count of matched edges on both images. It is equal to `count` if `goodMatchesFactor` does not limit the matches, otherwise it contains the total count of matches before `goodMatchesFactor` is applied.
    • getPoints1

      public List<org.openqa.selenium.Point> getPoints1()
      Returns a list of matching points on the first image.
      Returns:
      The list of matching points on the first image.
    • getRect1

      public org.openqa.selenium.Rectangle getRect1()
      Returns a rect for the `points1` list.
      Returns:
      The bounding rect for the `points1` list or a zero rect if not enough matching points were found.
    • getPoints2

      public List<org.openqa.selenium.Point> getPoints2()
      Returns a list of matching points on the second image.
      Returns:
      The list of matching points on the second image.
    • getRect2

      public org.openqa.selenium.Rectangle getRect2()
      Returns a rect for the `points2` list.
      Returns:
      The bounding rect for the `points2` list or a zero rect if not enough matching points were found.