Class IOSMobileCommandHelper

java.lang.Object
io.appium.java_client.MobileCommand
io.appium.java_client.ios.IOSMobileCommandHelper

@Deprecated public class IOSMobileCommandHelper extends MobileCommand
Deprecated.
  • Constructor Details

    • IOSMobileCommandHelper

      public IOSMobileCommandHelper()
      Deprecated.
  • Method Details

    • shakeCommand

      @Deprecated public static Map.Entry<String,Map<String,?>> shakeCommand()
      Deprecated.
      this helper is deprecated and will be removed in future versions.
      This method forms a Map of parameters for the device shaking.
      Returns:
      a key-value pair. The key is the command name. The value is a Map command arguments.
    • touchIdCommand

      @Deprecated public static Map.Entry<String,Map<String,?>> touchIdCommand(boolean match)
      Deprecated.
      this helper is deprecated and will be removed in future versions.
      This method forms a Map of parameters for the touchId simulator.
      Parameters:
      match - If true, simulates a successful fingerprint scan. If false, simulates a failed fingerprint scan.
      Returns:
      a key-value pair. The key is the command name. The value is a Map command arguments.
    • toggleTouchIdEnrollmentCommand

      @Deprecated public static Map.Entry<String,Map<String,?>> toggleTouchIdEnrollmentCommand(boolean enabled)
      Deprecated.
      this helper is deprecated and will be removed in future versions.
      This method forms a Map of parameters for the toggling touchId enrollment in simulator.
      Parameters:
      enabled - Whether to enable or disable Touch ID Enrollment for Simulator.
      Returns:
      a key-value pair. The key is the command name. The value is a Map command arguments.