Interface PerformsTouchID

All Superinterfaces:
ExecutesMethod
All Known Implementing Classes:
FlutterIOSDriver, IOSDriver

public interface PerformsTouchID extends ExecutesMethod
  • Method Summary

    Modifier and Type
    Method
    Description
    default void
    performTouchID(boolean match)
    Simulate touchId event on iOS Simulator.
    default void
    toggleTouchIDEnrollment(boolean enabled)
    Enrolls touchId in iOS Simulator.

    Methods inherited from interface io.appium.java_client.ExecutesMethod

    execute, execute
  • Method Details

    • performTouchID

      default void performTouchID(boolean match)
      Simulate touchId event on iOS Simulator. Check the documentation on 'mobile: sendBiometricMatch' extension for more details.
      Parameters:
      match - If true, simulates a successful fingerprint scan. If false, simulates a failed fingerprint scan.
    • toggleTouchIDEnrollment

      default void toggleTouchIDEnrollment(boolean enabled)
      Enrolls touchId in iOS Simulator. Check the documentation on 'mobile: enrollBiometric' extension for more details.
      Parameters:
      enabled - Whether to enable or disable Touch ID Enrollment. The actual state of the feature will only be changed if the current value is different from the previous one. Multiple calls of the method with the same argument value have no effect.