Interface SupportsKeychainsExcludePatternsOption<T extends BaseOptions<T>>

All Superinterfaces:
CanSetCapability<T>, org.openqa.selenium.Capabilities, Serializable
All Known Implementing Classes:
XCUITestOptions

public interface SupportsKeychainsExcludePatternsOption<T extends BaseOptions<T>> extends org.openqa.selenium.Capabilities, CanSetCapability<T>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
  • Method Summary

    Modifier and Type
    Method
    Description
    default Optional<String>
    Get keychains exclude patterns.
    default T
    This capability accepts comma-separated path patterns, which are going to be excluded from keychains restore while full reset is being performed on Simulator.

    Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability

    amend, setCapability

    Methods inherited from interface org.openqa.selenium.Capabilities

    asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
  • Field Details

  • Method Details

    • setKeychainsExcludePatterns

      default T setKeychainsExcludePatterns(String patterns)
      This capability accepts comma-separated path patterns, which are going to be excluded from keychains restore while full reset is being performed on Simulator. It might be useful if you want to exclude only particular keychain types from being restored, like the applications keychain. This feature has no effect on real devices. E.g. "*keychain*.db*" to exclude applications keychain from being restored
      Parameters:
      patterns - Comma-separated list of file exclude patterns.
      Returns:
      self instance for chaining.
    • getKeychainsExcludePatterns

      default Optional<String> getKeychainsExcludePatterns()
      Get keychains exclude patterns.
      Returns:
      Exclude patterns.