Class Mac2StartScreenRecordingOptions


public class Mac2StartScreenRecordingOptions extends BaseStartScreenRecordingOptions<Mac2StartScreenRecordingOptions>
  • Constructor Details

    • Mac2StartScreenRecordingOptions

      public Mac2StartScreenRecordingOptions()
  • Method Details

    • startScreenRecordingOptions

      public static Mac2StartScreenRecordingOptions startScreenRecordingOptions()
    • withFps

      public Mac2StartScreenRecordingOptions withFps(int fps)
      The count of frames per second in the resulting video. Increasing fps value also increases the size of the resulting video file and the CPU usage.
      Parameters:
      fps - The actual frames per second value. The default value is 15.
      Returns:
      self instance for chaining.
    • enableCursorCapture

      public Mac2StartScreenRecordingOptions enableCursorCapture()
      Whether to capture the mouse cursor while recording the screen. Disabled by default.
      Returns:
      self instance for chaining.
    • enableClicksCapture

      public Mac2StartScreenRecordingOptions enableClicksCapture()
      Whether to capture the click gestures while recording the screen. Disabled by default.
      Returns:
      self instance for chaining.
    • withDeviceId

      public Mac2StartScreenRecordingOptions withDeviceId(Integer deviceId)
      Screen device index to use for the recording. The list of available devices could be retrieved using `ffmpeg -f avfoundation -list_devices true -i` command. This option is mandatory and must be always provided.
      Parameters:
      deviceId - The valid screen device identifier.
      Returns:
      self instance for chaining.
    • withVideoFilter

      public Mac2StartScreenRecordingOptions withVideoFilter(String videoFilter)
      The video filter spec to apply for ffmpeg. See https://trac.ffmpeg.org/wiki/FilteringGuide for more details on the possible values. Example: Set it to `scale=ifnot(gte(iw\,1024)\,iw\,1024):-2` in order to limit the video width to 1024px. The height will be adjusted automatically to match the actual screen aspect ratio.
      Parameters:
      videoFilter - Valid ffmpeg video filter spec string.
      Returns:
      self instance for chaining.
    • withPreset

      public Mac2StartScreenRecordingOptions withPreset(String preset)
      A preset is a collection of options that will provide a certain encoding speed to compression ratio. A slower preset will provide better compression (compression is quality per filesize). This means that, for example, if you target a certain file size or constant bit rate, you will achieve better quality with a slower preset. Read https://trac.ffmpeg.org/wiki/Encode/H.264 for more details.
      Parameters:
      preset - One of the supported encoding presets. Possible values are: - ultrafast - superfast - veryfast (default) - faster - fast - medium - slow - slower - veryslow
      Returns:
      self instance for chaining.
    • withTimeLimit

      public Mac2StartScreenRecordingOptions withTimeLimit(Duration timeLimit)
      The maximum recording time. The default value is 600 seconds (10 minutes). The minimum time resolution unit is one second.
      Overrides:
      withTimeLimit in class BaseStartScreenRecordingOptions<Mac2StartScreenRecordingOptions>
      Parameters:
      timeLimit - The actual time limit of the recorded video.
      Returns:
      self instance for chaining.
    • build

      public Map<String,Object> build()
      Description copied from class: BaseScreenRecordingOptions
      Builds a map, which is ready to be passed to the subordinated Appium API.
      Overrides:
      build in class BaseStartScreenRecordingOptions<Mac2StartScreenRecordingOptions>
      Returns:
      arguments mapping.