Class Mac2Options
java.lang.Object
org.openqa.selenium.MutableCapabilities
io.appium.java_client.remote.options.BaseOptions<Mac2Options>
io.appium.java_client.mac.options.Mac2Options
- All Implemented Interfaces:
SupportsArgumentsOption<Mac2Options>,SupportsBootstrapRootOption<Mac2Options>,SupportsBundleIdOption<Mac2Options>,SupportsEnvironmentOption<Mac2Options>,SupportsServerStartupTimeoutOption<Mac2Options>,SupportsShowServerLogsOption<Mac2Options>,SupportsSkipAppKillOption<Mac2Options>,SupportsSystemHostOption<Mac2Options>,SupportsSystemPortOption<Mac2Options>,SupportsWebDriverAgentMacUrlOption<Mac2Options>,CanSetCapability<Mac2Options>,SupportsAutomationNameOption<Mac2Options>,SupportsBrowserNameOption<Mac2Options>,SupportsEventTimingsOption<Mac2Options>,SupportsFullResetOption<Mac2Options>,SupportsNewCommandTimeoutOption<Mac2Options>,SupportsNoResetOption<Mac2Options>,SupportsPlatformVersionOption<Mac2Options>,SupportsPostrunOption<Mac2Options,,AppleScriptData> SupportsPrerunOption<Mac2Options,,AppleScriptData> SupportsPrintPageSourceOnFindFailureOption<Mac2Options>,SupportsWebSocketUrlOption<Mac2Options>,Serializable,org.openqa.selenium.Capabilities
public class Mac2Options
extends BaseOptions<Mac2Options>
implements SupportsSystemPortOption<Mac2Options>, SupportsSystemHostOption<Mac2Options>, SupportsWebDriverAgentMacUrlOption<Mac2Options>, SupportsBootstrapRootOption<Mac2Options>, SupportsBundleIdOption<Mac2Options>, SupportsArgumentsOption<Mac2Options>, SupportsEnvironmentOption<Mac2Options>, SupportsServerStartupTimeoutOption<Mac2Options>, SupportsSkipAppKillOption<Mac2Options>, SupportsShowServerLogsOption<Mac2Options>, SupportsPrerunOption<Mac2Options,AppleScriptData>, SupportsPostrunOption<Mac2Options,AppleScriptData>
Provides options specific to the Appium Mac2 Driver.
For more details, refer to the capabilities documentation
- See Also:
-
Field Summary
Fields inherited from interface io.appium.java_client.mac.options.SupportsArgumentsOption
ARGUMENTS_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsAutomationNameOption
AUTOMATION_NAME_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsBootstrapRootOption
BOOTSTRAP_ROOT_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsBrowserNameOption
BROWSER_NAME_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsBundleIdOption
BUNDLE_ID_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsEnvironmentOption
ENVIRONMENT_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsEventTimingsOption
EVENT_TIMINGS_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsFullResetOption
FULL_RESET_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsNewCommandTimeoutOption
NEW_COMMAND_TIMEOUT_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsNoResetOption
NO_RESET_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPlatformVersionOption
PLATFORM_VERSION_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPostrunOption
POSTRUN_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPrerunOption
PRERUN_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPrintPageSourceOnFindFailureOption
PRINT_PAGE_SOURCE_ON_FIND_FAILURE_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsServerStartupTimeoutOption
SERVER_STARTUP_TIMEOUT_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsShowServerLogsOption
SHOW_SERVER_LOGS_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsSkipAppKillOption
SKIP_APP_KILL_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsSystemHostOption
SYSTEM_HOST_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsSystemPortOption
SYSTEM_PORT_OPTIONFields inherited from interface io.appium.java_client.mac.options.SupportsWebDriverAgentMacUrlOption
WEB_DRIVER_AGENT_MAC_URL_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsWebSocketUrlOption
WEB_SOCKET_URL -
Constructor Summary
ConstructorsConstructorDescriptionMac2Options(Map<String, ?> source) Mac2Options(org.openqa.selenium.Capabilities source) -
Method Summary
Modifier and TypeMethodDescriptionGet the postrun script.Get the prerun script.setPostrun(AppleScriptData script) An object containing either script or command key.setPrerun(AppleScriptData script) An object containing either script or command key.Methods inherited from class io.appium.java_client.remote.options.BaseOptions
asMap, clone, getCapability, getPlatformName, merge, setCapability, setPlatformName, toW3cNameMethods inherited from class org.openqa.selenium.MutableCapabilities
equals, getCapabilityNames, hashCode, setCapability, setCapability, setCapability, toJson, toStringMethods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, requiredMethods inherited from interface io.appium.java_client.mac.options.SupportsArgumentsOption
getArguments, setArgumentsMethods inherited from interface io.appium.java_client.remote.options.SupportsAutomationNameOption
getAutomationName, setAutomationNameMethods inherited from interface io.appium.java_client.mac.options.SupportsBootstrapRootOption
getBootstrapRoot, setBootstrapRootMethods inherited from interface io.appium.java_client.remote.options.SupportsBrowserNameOption
withBrowserNameMethods inherited from interface io.appium.java_client.mac.options.SupportsBundleIdOption
getBundleId, setBundleIdMethods inherited from interface io.appium.java_client.mac.options.SupportsEnvironmentOption
getEnvironment, setEnvironmentMethods inherited from interface io.appium.java_client.remote.options.SupportsEventTimingsOption
doesEventTimings, eventTimings, setEventTimingsMethods inherited from interface io.appium.java_client.remote.options.SupportsFullResetOption
doesFullReset, fullReset, setFullResetMethods inherited from interface io.appium.java_client.remote.options.SupportsNewCommandTimeoutOption
getNewCommandTimeout, setNewCommandTimeoutMethods inherited from interface io.appium.java_client.remote.options.SupportsNoResetOption
doesNoReset, noReset, setNoResetMethods inherited from interface io.appium.java_client.remote.options.SupportsPlatformVersionOption
getPlatformVersion, setPlatformVersionMethods inherited from interface io.appium.java_client.remote.options.SupportsPrintPageSourceOnFindFailureOption
doesPrintPageSourceOnFindFailure, printPageSourceOnFindFailure, setPrintPageSourceOnFindFailureMethods inherited from interface io.appium.java_client.mac.options.SupportsServerStartupTimeoutOption
getServerStartupTimeout, setServerStartupTimeoutMethods inherited from interface io.appium.java_client.mac.options.SupportsShowServerLogsOption
doesShowServerLogs, setShowServerLogs, showServerLogsMethods inherited from interface io.appium.java_client.mac.options.SupportsSkipAppKillOption
doesSkipAppKill, setSkipAppKill, skipAppKillMethods inherited from interface io.appium.java_client.mac.options.SupportsSystemHostOption
getSystemHost, setSystemHostMethods inherited from interface io.appium.java_client.mac.options.SupportsSystemPortOption
getSystemPort, setSystemPortMethods inherited from interface io.appium.java_client.mac.options.SupportsWebDriverAgentMacUrlOption
getWebDriverAgentMacUrl, setWebDriverAgentMacUrl, setWebDriverAgentMacUrlMethods inherited from interface io.appium.java_client.remote.options.SupportsWebSocketUrlOption
enableBiDi, getWebSocketUrl, setWebSocketUrl
-
Constructor Details
-
Mac2Options
public Mac2Options() -
Mac2Options
public Mac2Options(org.openqa.selenium.Capabilities source) -
Mac2Options
-
-
Method Details
-
setPrerun
An object containing either script or command key. The value of each key must be a valid AppleScript script or command to be executed after before Mac2Driver session is started. See https://github.com/appium/appium-mac2-driver#applescript-commands-execution for more details.- Specified by:
setPrerunin interfaceSupportsPrerunOption<Mac2Options,AppleScriptData> - Parameters:
script- A valid AppleScript snippet.- Returns:
- self instance for chaining.
-
getPrerun
Get the prerun script.- Specified by:
getPrerunin interfaceSupportsPrerunOption<Mac2Options,AppleScriptData> - Returns:
- Prerun script.
-
setPostrun
An object containing either script or command key. The value of each key must be a valid AppleScript script or command to be executed after Mac2Driver session is stopped. See https://github.com/appium/appium-mac2-driver#applescript-commands-execution for more details.- Specified by:
setPostrunin interfaceSupportsPostrunOption<Mac2Options,AppleScriptData> - Parameters:
script- A valid AppleScript snippet.- Returns:
- self instance for chaining.
-
getPostrun
Get the postrun script.- Specified by:
getPostrunin interfaceSupportsPostrunOption<Mac2Options,AppleScriptData> - Returns:
- Postrun script.
-