Package io.appium.java_client
package io.appium.java_client
-
ClassDescriptionA class to store the appium http client configuration.Default Appium driver implementation.Defines common error codes for the mobile JSON wire protocol.Represents the physical location.The repository of mobile commands defined in the Mobile JSON wire protocol.Deprecated.Touch actions are deprecated.PerformsActions<T extends PerformsActions<T>>Deprecated.Enums defining constants for Appium Settings which can be set and toggled during a test session.TouchAction<T extends TouchAction<T>>Deprecated.Touch actions are deprecated.