Annotation Interface AndroidFindBy


Used to mark a field on a Page Object to indicate an alternative mechanism for locating the element or a list of elements. Used in conjunction with PageFactory this allows users to quickly and easily create PageObjects. using Android UI selectors, accessibility, id, name, class name, tag and xpath
  • Element Details

    • uiAutomator

      String uiAutomator
      A String that can build an Android UiSelector or UiScrollable object. Refer to https://developer.android.com/training/testing/ui-automator
      Returns:
      an Android UIAutomator string
      Default:
      ""
    • accessibility

      String accessibility
      It an UI automation accessibility Id which is a convenient to Android. About Android accessibility https://developer.android.com/intl/ru/training/accessibility/accessible-app.html
      Returns:
      an UI automation accessibility Id
      Default:
      ""
    • id

      String id
      It is an id of the target element.
      Returns:
      an id of the target element
      Default:
      ""
    • className

      String className
      It is a className of the target element.
      Returns:
      a className of the target element
      Default:
      ""
    • tagName

      String tagName
      It is a desired element tag.
      Returns:
      a desired element tag
      Default:
      ""
    • androidDataMatcher

      String androidDataMatcher
      It is a desired data matcher expression.
      Returns:
      a desired data matcher expression
      Default:
      ""
    • androidViewMatcher

      String androidViewMatcher
      It is a desired view matcher expression.
      Returns:
      a desired view matcher expression
      Default:
      ""
    • xpath

      String xpath
      It is a xpath to the target element.
      Returns:
      a xpath to the target element
      Default:
      ""
    • priority

      int priority
      Priority of the searching. Higher number means lower priority.
      Returns:
      priority of the searching
      Default:
      0