Annotation Interface AndroidFindByAllSet


@Target({TYPE,FIELD}) @Retention(RUNTIME) public @interface AndroidFindByAllSet
Defines set of chained/possible locators. Each one locator should be defined with AndroidFindAll
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    An array which builds a sequence of the chained searching for elements or a set of possible locators.
  • Element Details

    • value

      An array which builds a sequence of the chained searching for elements or a set of possible locators.
      Returns:
      an array of AndroidFindAll which builds a sequence of the chained searching for elements or a set of possible locators