Annotation Interface AndroidFindByChainSet


@Target({TYPE,FIELD}) @Retention(RUNTIME) public @interface AndroidFindByChainSet
Defines set of chained/possible locators. Each one locator should be defined with AndroidFindBys
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    An array of which builds a sequence of the chained searching for elements or a set of possible locators.
  • Element Details

    • value

      An array of which builds a sequence of the chained searching for elements or a set of possible locators.
      Returns:
      an array of AndroidFindBys which builds a sequence of the chained searching for elements or a set of possible locators