Annotation Interface AndroidFindBySet


@Target({TYPE,FIELD}) @Retention(RUNTIME) public @interface AndroidFindBySet
Defines set of chained/possible locators. Each one locator should be defined with AndroidFindBy
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    An array of which builds a sequence of the chained searching for elements or a set of possible locators.
  • Element Details

    • value

      AndroidFindBy[] value
      An array of which builds a sequence of the chained searching for elements or a set of possible locators.
      Returns:
      an array of AndroidFindBy which builds a sequence of the chained searching for elements or a set of possible locators