Annotation Interface AndroidFindBys


Used to mark a field on a Page Object to indicate that lookup should use a series of AndroidBy tags.
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    It is a set of AndroidBy strategies which build the chain of the searching for the target element.
  • Optional Element Summary

    Optional Elements
    Modifier and Type
    Optional Element
    Description
    int
    Priority of the searching.
  • Element Details

    • value

      AndroidBy[] value
      It is a set of AndroidBy strategies which build the chain of the searching for the target element.
      Returns:
      a collection of strategies which build the chain of the searching for the target element
    • priority

      int priority
      Priority of the searching. Higher number means lower priority.
      Returns:
      priority of the searching
      Default:
      0