Annotation Interface HowToUseLocators


@Retention(RUNTIME) @Target({FIELD,TYPE}) public @interface HowToUseLocators
  • Element Details

    • androidAutomation

      LocatorGroupStrategy androidAutomation
      The strategy which defines how to use locators which are described by the AndroidFindBy annotation. These annotations can define the chained searching or the searching by all possible locators.
      Returns:
      the strategy which defines how to use locators which are described by the AndroidFindBy annotation
      Default:
      CHAIN
    • iOSXCUITAutomation

      LocatorGroupStrategy iOSXCUITAutomation
      The strategy which defines how to use locators which are described by the iOSXCUITFindBy annotation. These annotations can define the chained searching or the searching by all possible locators.
      Returns:
      the strategy which defines how to use locators which are described by the iOSXCUITFindBy annotation
      Default:
      CHAIN