Annotation Interface iOSXCUITFindByChainSet


@Target({TYPE,FIELD}) @Retention(RUNTIME) public @interface iOSXCUITFindByChainSet
Defines set of chained/possible locators. Each one locator should be defined with iOSXCUITFindBys
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    An array of which builds a sequence of the chained searching for elements or a set of possible locators.
  • Element Details

    • value

      An array of which builds a sequence of the chained searching for elements or a set of possible locators.
      Returns:
      an array of iOSXCUITFindBys which builds a sequence of the chained searching for elements or a set of possible locators