Annotation Interface iOSXCUITFindBySet


@Retention(RUNTIME) @Target({FIELD,TYPE}) public @interface iOSXCUITFindBySet
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    An array of which builds a sequence of the chained searching for elements or a set of possible locators.
  • Element Details

    • value

      An array of which builds a sequence of the chained searching for elements or a set of possible locators.
      Returns:
      an array of iOSXCUITFindBy which builds a sequence of the chained searching for elements or a set of possible locators