Class ProxyFactory

java.lang.Object
io.appium.java_client.pagefactory.utils.ProxyFactory

public final class ProxyFactory extends Object
Original class is a super class of a proxy object here.
  • Method Details

    • getEnhancedProxy

      public static <T> T getEnhancedProxy(Class<T> requiredClazz, MethodCallListener listener)
      Creates a proxy instance for the given class with an empty constructor.
      Type Parameters:
      T - The proxy object class.
      Parameters:
      requiredClazz - is a Class whose instance should be created
      listener - is the instance of a method listener class
      Returns:
      a proxied instance of the desired class
    • getEnhancedProxy

      public static <T> T getEnhancedProxy(Class<T> cls, Class<?>[] params, Object[] values, MethodCallListener listener)
      Creates a proxy instance for the given class.
      Type Parameters:
      T - The proxy object class.
      Parameters:
      cls - is a Class whose instance should be created
      params - is an array of @link java.lang.Class}. It should be convenient to parameter types of some declared constructor which belongs to desired class.
      values - is an array of @link java.lang.Object}. It should be convenient to parameter types of some declared constructor which belongs to desired class.
      listener - is the instance of a method listener class
      Returns:
      a proxied instance of the desired class