Class StorageClient

java.lang.Object
io.appium.java_client.plugins.storage.StorageClient

public class StorageClient extends Object
This is a Java implementation of the Appium server storage plugin client. See the plugin README for more details.
  • Field Details

  • Constructor Details

    • StorageClient

      public StorageClient(URL baseUrl)
    • StorageClient

      public StorageClient(org.openqa.selenium.remote.http.ClientConfig clientConfig)
  • Method Details

    • add

      public void add(File file)
      Adds a local file to the server storage. The remote file name is be set to the same value as the local file name.
      Parameters:
      file - File instance.
    • add

      public void add(File file, String name)
      Adds a local file to the server storage.
      Parameters:
      file - File instance.
      name - The remote file name.
    • list

      public List<StorageItem> list()
      Lists items that exist in the storage.
      Returns:
      All storage items.
    • delete

      public boolean delete(String name)
      Deletes an item from the server storage.
      Parameters:
      name - The name of the item to be deleted.
      Returns:
      true if the dletion was successful.
    • reset

      public void reset()
      Resets all items of the server storage.