Class StorageUtils

java.lang.Object
io.appium.java_client.plugins.storage.StorageUtils

public class StorageUtils extends Object
  • Method Details

    • calcSha1Digest

      public static String calcSha1Digest(File source)
      Calculates SHA1 hex digest of the given file.
      Parameters:
      source - The file instance to calculate the hash for.
      Returns:
      Hash digest represented as a string of hexadecimal numbers.
    • streamFileToWebSocket

      public static void streamFileToWebSocket(File source, org.openqa.selenium.remote.http.WebSocket socket)
      Feeds the content of the given file to the provided web socket.
      Parameters:
      source - The source file instance.
      socket - The destination web socket.