Package io.appium.java_client.proxy
package io.appium.java_client.proxy
-
ClassDescriptionExtension of
MethodCallListenerthat allows access to the proxy instance it depends on.
MethodCallListener that allows access to the proxy instance it depends on.