Class AppiumW3CHttpCommandCodec

java.lang.Object
org.openqa.selenium.remote.codec.AbstractHttpCommandCodec
org.openqa.selenium.remote.codec.w3c.W3CHttpCommandCodec
io.appium.java_client.remote.AppiumW3CHttpCommandCodec
All Implemented Interfaces:
org.openqa.selenium.remote.CommandCodec<org.openqa.selenium.remote.http.HttpRequest>

public class AppiumW3CHttpCommandCodec extends org.openqa.selenium.remote.codec.w3c.W3CHttpCommandCodec
  • Nested Class Summary

    Nested classes/interfaces inherited from class org.openqa.selenium.remote.codec.AbstractHttpCommandCodec

    org.openqa.selenium.remote.codec.AbstractHttpCommandCodec.CommandSpec
  • Constructor Summary

    Constructors
    Constructor
    Description
    This class overrides the built-in Selenium W3C commands codec, since the latter hardcodes many commands in Javascript, which does not work with Appium.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    alias(String commandName, String isAnAliasFor)
     
    protected Map<String,?>
    amendParameters(String name, Map<String,?> parameters)
     

    Methods inherited from class org.openqa.selenium.remote.codec.AbstractHttpCommandCodec

    decode, defineCommand, defineCommand, delete, encode, get, isSupported, post

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • AppiumW3CHttpCommandCodec

      public AppiumW3CHttpCommandCodec()
      This class overrides the built-in Selenium W3C commands codec, since the latter hardcodes many commands in Javascript, which does not work with Appium. Check https://www.w3.org/TR/webdriver/ to see all available W3C endpoints.
  • Method Details

    • alias

      public void alias(String commandName, String isAnAliasFor)
      Specified by:
      alias in interface org.openqa.selenium.remote.CommandCodec<org.openqa.selenium.remote.http.HttpRequest>
      Overrides:
      alias in class org.openqa.selenium.remote.codec.AbstractHttpCommandCodec
    • amendParameters

      protected Map<String,?> amendParameters(String name, Map<String,?> parameters)
      Overrides:
      amendParameters in class org.openqa.selenium.remote.codec.w3c.W3CHttpCommandCodec