Enum Class UnhandledPromptBehavior
java.lang.Object
java.lang.Enum<UnhandledPromptBehavior>
io.appium.java_client.remote.options.UnhandledPromptBehavior
- All Implemented Interfaces:
Serializable,Comparable<UnhandledPromptBehavior>,Constable
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionstatic UnhandledPromptBehaviorfromString(String value) Converts the given value to an enum member.toString()static UnhandledPromptBehaviorReturns the enum constant of this class with the specified name.static UnhandledPromptBehavior[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
DISMISS
-
ACCEPT
-
DISMISS_AND_NOTIFY
-
ACCEPT_AND_NOTIFY
-
IGNORE
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
toString
- Overrides:
toStringin classEnum<UnhandledPromptBehavior>
-
fromString
Converts the given value to an enum member.- Parameters:
value- The value to convert.- Returns:
- Enum member.
- Throws:
IllegalArgumentException- If the provided value cannot be matched.
-