Class BaseScreenRecordingOptions<T extends BaseScreenRecordingOptions<T>>
java.lang.Object
io.appium.java_client.screenrecording.BaseScreenRecordingOptions<T>
- Direct Known Subclasses:
BaseStartScreenRecordingOptions,BaseStopScreenRecordingOptions
public abstract class BaseScreenRecordingOptions<T extends BaseScreenRecordingOptions<T>>
extends Object
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a map, which is ready to be passed to the subordinated Appium API.protected TwithUploadOptions(ScreenRecordingUploadOptions uploadOptions) Upload options set for the recorded screen capture.
-
Constructor Details
-
BaseScreenRecordingOptions
public BaseScreenRecordingOptions()
-
-
Method Details
-
withUploadOptions
Upload options set for the recorded screen capture.- Parameters:
uploadOptions- see the documentation onScreenRecordingUploadOptionsfor more details.- Returns:
- self instance for chaining.
-
build
Builds a map, which is ready to be passed to the subordinated Appium API.- Returns:
- arguments mapping.
-