Class BaseStartScreenRecordingOptions<T extends BaseStartScreenRecordingOptions<T>>

java.lang.Object
io.appium.java_client.screenrecording.BaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T>>
io.appium.java_client.screenrecording.BaseStartScreenRecordingOptions<T>
Direct Known Subclasses:
AndroidStartScreenRecordingOptions, IOSStartScreenRecordingOptions, Mac2StartScreenRecordingOptions, WindowsStartScreenRecordingOptions

public abstract class BaseStartScreenRecordingOptions<T extends BaseStartScreenRecordingOptions<T>> extends BaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T>>
  • Constructor Details

    • BaseStartScreenRecordingOptions

      public BaseStartScreenRecordingOptions()
  • Method Details

    • withTimeLimit

      public T withTimeLimit(Duration timeLimit)
      The maximum recording time.
      Parameters:
      timeLimit - The actual time limit of the recorded video.
      Returns:
      self instance for chaining.
    • enableForcedRestart

      public T enableForcedRestart()
      Whether to ignore the result of previous capture and start a new recording immediately.
      Returns:
      self instance for chaining.
    • disableForcedRestart

      public T disableForcedRestart()
      Whether to return silently if there is an active video recording.
      Returns:
      self instance for chaining.
    • build

      public Map<String,Object> build()
      Description copied from class: BaseScreenRecordingOptions
      Builds a map, which is ready to be passed to the subordinated Appium API.
      Overrides:
      build in class BaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T extends BaseStartScreenRecordingOptions<T>>>
      Returns:
      arguments mapping.