Class BaseStopScreenRecordingOptions<T extends BaseStopScreenRecordingOptions<T>>
java.lang.Object
io.appium.java_client.screenrecording.BaseScreenRecordingOptions<BaseStopScreenRecordingOptions<T>>
io.appium.java_client.screenrecording.BaseStopScreenRecordingOptions<T>
- Direct Known Subclasses:
AndroidStopScreenRecordingOptions,IOSStopScreenRecordingOptions,Mac2StopScreenRecordingOptions,WindowsStopScreenRecordingOptions
public abstract class BaseStopScreenRecordingOptions<T extends BaseStopScreenRecordingOptions<T>>
extends BaseScreenRecordingOptions<BaseStopScreenRecordingOptions<T>>
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionwithUploadOptions(ScreenRecordingUploadOptions uploadOptions) The remotePath upload option is the path to the remote location, where the resulting video should be uploaded.Methods inherited from class io.appium.java_client.screenrecording.BaseScreenRecordingOptions
build
-
Constructor Details
-
BaseStopScreenRecordingOptions
public BaseStopScreenRecordingOptions()
-
-
Method Details
-
withUploadOptions
The remotePath upload option is the path to the remote location, where the resulting video should be uploaded. The following protocols are supported: http/https (multipart), ftp. Missing value (the default setting) means the content of resulting file should be encoded as Base64 and passed as the endpoint response value, but an exception will be thrown if the generated media file is too big to fit into the available process memory.- Overrides:
withUploadOptionsin classBaseScreenRecordingOptions<BaseStopScreenRecordingOptions<T extends BaseStopScreenRecordingOptions<T>>>- Parameters:
uploadOptions- see the documentation onScreenRecordingUploadOptionsfor more details.- Returns:
- self instance for chaining.
-