Enum Class AndroidServerFlag

java.lang.Object
java.lang.Enum<AndroidServerFlag>
io.appium.java_client.service.local.flags.AndroidServerFlag
All Implemented Interfaces:
ServerArgument, Serializable, Comparable<AndroidServerFlag>, Constable

public enum AndroidServerFlag extends Enum<AndroidServerFlag> implements ServerArgument
Here is the list of Android specific server arguments.
  • Enum Constant Details

    • BOOTSTRAP_PORT_NUMBER

      public static final AndroidServerFlag BOOTSTRAP_PORT_NUMBER
      Port to use on device to talk to Appium. Sample: --bootstrap-port 4724
    • SUPPRESS_ADB_KILL_SERVER

      public static final AndroidServerFlag SUPPRESS_ADB_KILL_SERVER
      If set, prevents Appium from killing the adb server instance. Default: false
    • CHROME_DRIVER_PORT

      public static final AndroidServerFlag CHROME_DRIVER_PORT
      Port upon which ChromeDriver will run. Sample: --chromedriver-port 9515
    • CHROME_DRIVER_EXECUTABLE

      public static final AndroidServerFlag CHROME_DRIVER_EXECUTABLE
      ChromeDriver executable full path.
    • REBOOT

      public static final AndroidServerFlag REBOOT
  • Method Details

    • values

      public static AndroidServerFlag[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static AndroidServerFlag valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getArgument

      public String getArgument()
      Specified by:
      getArgument in interface ServerArgument