Class ActionOptions<T extends ActionOptions<T>>

java.lang.Object
io.appium.java_client.touch.ActionOptions<T>
Direct Known Subclasses:
AbstractOptionCombinedWithPosition, PointOption, WaitOptions

@Deprecated public abstract class ActionOptions<T extends ActionOptions<T>> extends Object
Deprecated.
  • Constructor Summary

    Constructors
    Constructor
    Description
    Deprecated.
     
  • Method Summary

    Modifier and Type
    Method
    Description
    Deprecated.
    Creates a map based on the provided options.
    protected abstract void
    Deprecated.
    This method is automatically called before building options map to verify the consistency of the instance.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • ActionOptions

      public ActionOptions()
      Deprecated.
  • Method Details

    • verify

      protected abstract void verify()
      Deprecated.
      This method is automatically called before building options map to verify the consistency of the instance.
      Throws:
      IllegalArgumentException - if there are problems with this options map.
    • build

      public Map<String,Object> build()
      Deprecated.
      Creates a map based on the provided options.
      Returns:
      options mapping.