Package io.appium.java_client.touch
Class WaitOptions
Deprecated.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Deprecated.Creates a map based on the provided options.protected voidverify()Deprecated.This method is automatically called before building options map to verify the consistency of the instance.static WaitOptionswaitOptions(Duration duration) Deprecated.Creates and instance ofWaitOptions.withDuration(Duration duration) Deprecated.Set the wait duration.
-
Field Details
-
duration
Deprecated.
-
-
Constructor Details
-
WaitOptions
public WaitOptions()Deprecated.
-
-
Method Details
-
waitOptions
Deprecated.Creates and instance ofWaitOptions.- Parameters:
duration- is the duration of the waiting.- Returns:
- a built option.
-
withDuration
Deprecated.Set the wait duration.- Parameters:
duration- the value to set. Time resolution unit is 1 ms.- Returns:
- this instance for chaining.
-
verify
protected void verify()Deprecated.Description copied from class:ActionOptionsThis method is automatically called before building options map to verify the consistency of the instance.- Specified by:
verifyin classActionOptions<WaitOptions>
-
build
Deprecated.Description copied from class:ActionOptionsCreates a map based on the provided options.- Overrides:
buildin classActionOptions<WaitOptions>- Returns:
- options mapping.
-