Class AbstractOptionCombinedWithPosition<T extends AbstractOptionCombinedWithPosition<T>>
java.lang.Object
io.appium.java_client.touch.ActionOptions<AbstractOptionCombinedWithPosition<T>>
io.appium.java_client.touch.offset.AbstractOptionCombinedWithPosition<T>
- Direct Known Subclasses:
IOSPressOptions,LongPressOptions,TapOptions
@Deprecated
public abstract class AbstractOptionCombinedWithPosition<T extends AbstractOptionCombinedWithPosition<T>>
extends ActionOptions<AbstractOptionCombinedWithPosition<T>>
Deprecated.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Deprecated.Creates a map based on the provided options.protected voidverify()Deprecated.This method is automatically called before building options map to verify the consistency of the instance.withElement(ElementOption element) Deprecated.Most of touch action may use position which is relative to some element.withPosition(PointOption positionOption) Deprecated.Some actions may require coordinates.
-
Constructor Details
-
AbstractOptionCombinedWithPosition
public AbstractOptionCombinedWithPosition()Deprecated.
-
-
Method Details
-
withPosition
Deprecated.Some actions may require coordinates. Invocation of this method replaces the result of previouswithElement(ElementOption)invocation.- Parameters:
positionOption- required coordinates. *- Returns:
- self-reference
-
withElement
Deprecated.Most of touch action may use position which is relative to some element. In order to unify this behaviour this method was added. Invocation of this method replaces the result of previouswithPosition(PointOption)invocation.- Parameters:
element- required position which is relative to some element- Returns:
- self-reference
-
verify
protected void verify()Deprecated.Description copied from class:ActionOptionsThis method is automatically called before building options map to verify the consistency of the instance.- Specified by:
verifyin classActionOptions<AbstractOptionCombinedWithPosition<T extends AbstractOptionCombinedWithPosition<T>>>
-
build
Deprecated.Description copied from class:ActionOptionsCreates a map based on the provided options.- Overrides:
buildin classActionOptions<AbstractOptionCombinedWithPosition<T extends AbstractOptionCombinedWithPosition<T>>>- Returns:
- options mapping.
-