Class ElementOption


@Deprecated public class ElementOption extends PointOption<ElementOption>
Deprecated.
  • Constructor Details

    • ElementOption

      public ElementOption()
      Deprecated.
  • Method Details

    • element

      public static ElementOption element(org.openqa.selenium.WebElement element, org.openqa.selenium.Point offset)
      Deprecated.
      This method creates a build instance of the ElementOption.
      Parameters:
      element - is the element to calculate offset from.
      offset - is the offset from the upper left corner of the given element.
      Returns:
      the built option
    • element

      public static ElementOption element(org.openqa.selenium.WebElement element, int x, int y)
      Deprecated.
      This method creates a build instance of the ElementOption.
      Parameters:
      element - is the element to calculate offset from.
      x - is the x-offset from the upper left corner of the given element.
      y - is the y-offset from the upper left corner of the given element.
      Returns:
      the built option
    • element

      public static ElementOption element(org.openqa.selenium.WebElement element)
      Deprecated.
      This method creates a build instance of the ElementOption.
      Parameters:
      element - is the element to calculate offset from.
      Returns:
      the built option
    • withCoordinates

      public ElementOption withCoordinates(org.openqa.selenium.Point offset)
      Deprecated.
      It defines x and y offset from the upper left corner of an element.
      Overrides:
      withCoordinates in class PointOption<ElementOption>
      Parameters:
      offset - is the offset from the upper left corner of the given element.
      Returns:
      self-reference
    • withCoordinates

      public ElementOption withCoordinates(int xOffset, int yOffset)
      Deprecated.
      It defines x and y offset from the upper left corner of an element.
      Overrides:
      withCoordinates in class PointOption<ElementOption>
      Parameters:
      xOffset - is the x-offset from the upper left corner of the given element.
      yOffset - is the y-offset from the upper left corner of the given element.
      Returns:
      self-reference
    • withElement

      public ElementOption withElement(org.openqa.selenium.WebElement element)
      Deprecated.
      This method sets the element as an option. It means that x/y offset is the offset from the upper left corner of the given element.
      Parameters:
      element - is the element to calculate offset from.
      Returns:
      self-reference
    • verify

      protected void verify()
      Deprecated.
      Description copied from class: ActionOptions
      This method is automatically called before building options map to verify the consistency of the instance.
      Overrides:
      verify in class PointOption<ElementOption>
    • build

      public Map<String,Object> build()
      Deprecated.
      Description copied from class: ActionOptions
      Creates a map based on the provided options.
      Overrides:
      build in class PointOption<ElementOption>
      Returns:
      options mapping.