Class PointOption<T extends PointOption<T>>

java.lang.Object
io.appium.java_client.touch.ActionOptions<T>
io.appium.java_client.touch.offset.PointOption<T>
Direct Known Subclasses:
ElementOption

@Deprecated public class PointOption<T extends PointOption<T>> extends ActionOptions<T>
Deprecated.
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    protected org.openqa.selenium.Point
    Deprecated.
     
  • Constructor Summary

    Constructors
    Constructor
    Description
    Deprecated.
     
  • Method Summary

    Modifier and Type
    Method
    Description
    Deprecated.
    Creates a map based on the provided options.
    point(int xOffset, int yOffset)
    Deprecated.
    It creates a built instance of PointOption which takes x and y coordinates.
    point(org.openqa.selenium.Point offset)
    Deprecated.
    It creates a built instance of PointOption which takes x and y coordinates.
    protected void
    Deprecated.
    This method is automatically called before building options map to verify the consistency of the instance.
    withCoordinates(int xOffset, int yOffset)
    Deprecated.
    It defines x and y coordinates.
    withCoordinates(org.openqa.selenium.Point offset)
    Deprecated.
    It defines x and y coordinates.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • coordinates

      protected org.openqa.selenium.Point coordinates
      Deprecated.
  • Constructor Details

    • PointOption

      public PointOption()
      Deprecated.
  • Method Details

    • point

      public static PointOption point(org.openqa.selenium.Point offset)
      Deprecated.
      It creates a built instance of PointOption which takes x and y coordinates. This is offset from the upper left corner of the screen.
      Parameters:
      offset - is an offset value.
      Returns:
      a built option
    • point

      public static PointOption point(int xOffset, int yOffset)
      Deprecated.
      It creates a built instance of PointOption which takes x and y coordinates. This is offset from the upper left corner of the screen.
      Parameters:
      xOffset - is x value.
      yOffset - is y value.
      Returns:
      a built option
    • withCoordinates

      public T withCoordinates(org.openqa.selenium.Point offset)
      Deprecated.
      It defines x and y coordinates. This is offset from the upper left corner of the screen.
      Parameters:
      offset - is an offset value.
      Returns:
      self-reference
    • withCoordinates

      public T withCoordinates(int xOffset, int yOffset)
      Deprecated.
      It defines x and y coordinates. This is offset from the upper left corner of the screen.
      Parameters:
      xOffset - is x value.
      yOffset - is y value.
      Returns:
      self-reference
    • verify

      protected void verify()
      Deprecated.
      Description copied from class: ActionOptions
      This method is automatically called before building options map to verify the consistency of the instance.
      Specified by:
      verify in class ActionOptions<T extends PointOption<T>>
    • build

      public Map<String,Object> build()
      Deprecated.
      Description copied from class: ActionOptions
      Creates a map based on the provided options.
      Overrides:
      build in class ActionOptions<T extends PointOption<T>>
      Returns:
      options mapping.