Package io.appium.java_client.windows
Class WindowsDriver
java.lang.Object
org.openqa.selenium.remote.RemoteWebDriver
io.appium.java_client.AppiumDriver
io.appium.java_client.windows.WindowsDriver
- All Implemented Interfaces:
CanRememberExtensionPresence,ComparesImages,ExecutesDriverScript,ExecutesMethod,HasBrowserCheck,HasSettings,LogsEvents,PerformsTouchActions,PullsFiles,PushesFiles,CanRecordScreen,org.openqa.selenium.bidi.HasBiDi,org.openqa.selenium.federatedcredentialmanagement.HasFederatedCredentialManagement,org.openqa.selenium.HasCapabilities,org.openqa.selenium.HasDownloads,org.openqa.selenium.interactions.Interactive,org.openqa.selenium.JavascriptExecutor,org.openqa.selenium.PrintsPage,org.openqa.selenium.SearchContext,org.openqa.selenium.TakesScreenshot,org.openqa.selenium.virtualauthenticator.HasVirtualAuthenticator,org.openqa.selenium.WebDriver
public class WindowsDriver
extends AppiumDriver
implements PerformsTouchActions, PullsFiles, PushesFiles, CanRecordScreen
-
Nested Class Summary
Nested classes/interfaces inherited from class org.openqa.selenium.remote.RemoteWebDriver
org.openqa.selenium.remote.RemoteWebDriver.RemoteTargetLocator, org.openqa.selenium.remote.RemoteWebDriver.RemoteWebDriverOptions, org.openqa.selenium.remote.RemoteWebDriver.WhenNested classes/interfaces inherited from interface org.openqa.selenium.HasDownloads
org.openqa.selenium.HasDownloads.DownloadedFileNested classes/interfaces inherited from interface org.openqa.selenium.WebDriver
org.openqa.selenium.WebDriver.Navigation, org.openqa.selenium.WebDriver.Options, org.openqa.selenium.WebDriver.TargetLocator, org.openqa.selenium.WebDriver.Timeouts, org.openqa.selenium.WebDriver.Window -
Field Summary
Fields inherited from class org.openqa.selenium.remote.RemoteWebDriver
capabilitiesFields inherited from interface io.appium.java_client.HasBrowserCheck
NATIVE_CONTEXT -
Constructor Summary
ConstructorsConstructorDescriptionWindowsDriver(AppiumClientConfig appiumClientConfig, org.openqa.selenium.Capabilities capabilities) Creates a new instance based on the given ClientConfig andcapabilities.WindowsDriver(AppiumDriverLocalService service, org.openqa.selenium.Capabilities capabilities) WindowsDriver(AppiumDriverLocalService service, org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) WindowsDriver(AppiumServiceBuilder builder, org.openqa.selenium.Capabilities capabilities) WindowsDriver(AppiumServiceBuilder builder, org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) WindowsDriver(URL remoteSessionAddress) WindowsDriver(URL remoteAddress, org.openqa.selenium.Capabilities capabilities) WindowsDriver(URL remoteAddress, org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) WindowsDriver(org.openqa.selenium.Capabilities capabilities) WindowsDriver(org.openqa.selenium.remote.http.ClientConfig clientConfig, org.openqa.selenium.Capabilities capabilities) Creates a new instance based on the given ClientConfig andcapabilities.WindowsDriver(org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) WindowsDriver(org.openqa.selenium.remote.HttpCommandExecutor executor, org.openqa.selenium.Capabilities capabilities) -
Method Summary
Methods inherited from class io.appium.java_client.AppiumDriver
addCommand, assertExtensionExists, ensureAutomationName, ensurePlatformAndAutomationNames, ensurePlatformName, execute, execute, getBiDi, getExecuteMethod, getHttpClient, getScreenshotAs, getStatus, markExtensionAbsence, maybeGetBiDi, startSessionMethods inherited from class org.openqa.selenium.remote.RemoteWebDriver
addVirtualAuthenticator, builder, close, deleteDownloadableFiles, downloadFile, execute, executeAsyncScript, executeScript, findElement, findElements, findElements, fireSessionEvent, fireSessionEvent, get, getCapabilities, getClientConfig, getCommandExecutor, getCurrentUrl, getDownloadableFiles, getDownloadedFiles, getElementConverter, getErrorHandler, getFederatedCredentialManagementDialog, getFileDetector, getPageSource, getSessionId, getTitle, getWindowHandle, getWindowHandles, isDownloadsEnabled, log, manage, navigate, network, perform, print, quit, removeVirtualAuthenticator, resetCooldown, resetInputState, script, setCommandExecutor, setDelayEnabled, setElementConverter, setErrorHandler, setFileDetector, setFoundBy, setLogLevel, setSessionId, switchTo, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface io.appium.java_client.screenrecording.CanRecordScreen
startRecordingScreen, startRecordingScreen, stopRecordingScreen, stopRecordingScreenMethods inherited from interface io.appium.java_client.CanRememberExtensionPresence
assertExtensionExists, markExtensionAbsenceMethods inherited from interface io.appium.java_client.ComparesImages
findImageOccurrence, findImageOccurrence, findImageOccurrence, findImageOccurrence, getImagesSimilarity, getImagesSimilarity, getImagesSimilarity, getImagesSimilarity, matchImagesFeatures, matchImagesFeatures, matchImagesFeatures, matchImagesFeaturesMethods inherited from interface io.appium.java_client.ExecutesDriverScript
executeDriverScript, executeDriverScriptMethods inherited from interface io.appium.java_client.ExecutesMethod
execute, executeMethods inherited from interface io.appium.java_client.HasBrowserCheck
isBrowserMethods inherited from interface org.openqa.selenium.HasCapabilities
getCapabilitiesMethods inherited from interface org.openqa.selenium.HasDownloads
requireDownloadsEnabledMethods inherited from interface io.appium.java_client.HasSettings
getSettings, setSetting, setSetting, setSettings, setSettingsMethods inherited from interface org.openqa.selenium.JavascriptExecutor
executeScript, getPinnedScripts, pin, unpinMethods inherited from interface io.appium.java_client.LogsEvents
getEvents, logEventMethods inherited from interface io.appium.java_client.PerformsTouchActions
performMultiTouchAction, performTouchActionMethods inherited from interface io.appium.java_client.PullsFiles
pullFile, pullFolderMethods inherited from interface io.appium.java_client.PushesFiles
pushFile, pushFile
-
Constructor Details
-
WindowsDriver
public WindowsDriver(org.openqa.selenium.remote.HttpCommandExecutor executor, org.openqa.selenium.Capabilities capabilities) -
WindowsDriver
-
WindowsDriver
public WindowsDriver(URL remoteAddress, org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) -
WindowsDriver
public WindowsDriver(AppiumDriverLocalService service, org.openqa.selenium.Capabilities capabilities) -
WindowsDriver
public WindowsDriver(AppiumDriverLocalService service, org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) -
WindowsDriver
-
WindowsDriver
public WindowsDriver(AppiumServiceBuilder builder, org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) -
WindowsDriver
public WindowsDriver(org.openqa.selenium.remote.http.HttpClient.Factory httpClientFactory, org.openqa.selenium.Capabilities capabilities) -
WindowsDriver
-
WindowsDriver
public WindowsDriver(org.openqa.selenium.remote.http.ClientConfig clientConfig, org.openqa.selenium.Capabilities capabilities) Creates a new instance based on the given ClientConfig andcapabilities. The HTTP client is default client generated byHttpCommandExecutor.getDefaultClientFactory(). For example:ClientConfig clientConfig = ClientConfig.defaultConfig() .baseUri(URI.create("WebDriver URL")) .readTimeout(Duration.ofMinutes(5)); WindowsOptions options = new WindowsOptions(); WindowsDriver driver = new WindowsDriver(clientConfig, options);- Parameters:
clientConfig- take a look atClientConfigcapabilities- take a look atCapabilities
-
WindowsDriver
public WindowsDriver(AppiumClientConfig appiumClientConfig, org.openqa.selenium.Capabilities capabilities) Creates a new instance based on the given ClientConfig andcapabilities. The HTTP client is default client generated byHttpCommandExecutor.getDefaultClientFactory(). For example:AppiumClientConfig appiumClientConfig = AppiumClientConfig.defaultConfig() .directConnect(true) .baseUri(URI.create("WebDriver URL")) .readTimeout(Duration.ofMinutes(5)); WindowsOptions options = new WindowsOptions(); WindowsDriver driver = new WindowsDriver(appiumClientConfig, options);- Parameters:
appiumClientConfig- take a look atAppiumClientConfigcapabilities- take a look atCapabilities
-
WindowsDriver
public WindowsDriver(org.openqa.selenium.Capabilities capabilities)
-
-
Method Details
-
launchApp
public void launchApp()Launch the application app under test after it was closed. -
closeApp
public void closeApp()Close the app under test.
-