Class WindowsStartScreenRecordingOptions


public class WindowsStartScreenRecordingOptions extends BaseStartScreenRecordingOptions<WindowsStartScreenRecordingOptions>
  • Constructor Details

    • WindowsStartScreenRecordingOptions

      public WindowsStartScreenRecordingOptions()
  • Method Details

    • startScreenRecordingOptions

      public static WindowsStartScreenRecordingOptions startScreenRecordingOptions()
    • withFps

      public WindowsStartScreenRecordingOptions withFps(int fps)
      The count of frames per second in the resulting video. Increasing fps value also increases the size of the resulting video file and the CPU usage.
      Parameters:
      fps - The actual frames per second value. The default value is 15.
      Returns:
      self instance for chaining.
    • enableCursorCapture

      public WindowsStartScreenRecordingOptions enableCursorCapture()
      Whether to capture the mouse cursor while recording the screen. Disabled by default.
      Returns:
      self instance for chaining.
    • enableClicksCapture

      public WindowsStartScreenRecordingOptions enableClicksCapture()
      Whether to capture the click gestures while recording the screen. Disabled by default.
      Returns:
      self instance for chaining.
    • withAudioInput

      public WindowsStartScreenRecordingOptions withAudioInput(String audioInput)
      If provided then the given audio input will be used to record the computer audio along with the desktop video. The list of available devices could be retrieved using `ffmpeg -list_devices true -f dshow -i dummy` command.
      Parameters:
      audioInput - One of valid audio input names listed by ffmpeg
      Returns:
      self instance for chaining.
    • withVideoFilter

      public WindowsStartScreenRecordingOptions withVideoFilter(String videoFilter)
      The video filter spec to apply for ffmpeg. See https://trac.ffmpeg.org/wiki/FilteringGuide for more details on the possible values. Example: Set it to `scale=ifnot(gte(iw\,1024)\,iw\,1024):-2` in order to limit the video width to 1024px. The height will be adjusted automatically to match the actual screen aspect ratio.
      Parameters:
      videoFilter - Valid ffmpeg video filter spec string.
      Returns:
      self instance for chaining.
    • withPreset

      public WindowsStartScreenRecordingOptions withPreset(String preset)
      A preset is a collection of options that will provide a certain encoding speed to compression ratio. A slower preset will provide better compression (compression is quality per filesize). This means that, for example, if you target a certain file size or constant bit rate, you will achieve better quality with a slower preset. Read https://trac.ffmpeg.org/wiki/Encode/H.264 for more details.
      Parameters:
      preset - One of the supported encoding presets. Possible values are: - ultrafast - superfast - veryfast (default) - faster - fast - medium - slow - slower - veryslow
      Returns:
      self instance for chaining.
    • withTimeLimit

      public WindowsStartScreenRecordingOptions withTimeLimit(Duration timeLimit)
      The maximum recording time. The default value is 600 seconds (10 minutes). The minimum time resolution unit is one second.
      Overrides:
      withTimeLimit in class BaseStartScreenRecordingOptions<WindowsStartScreenRecordingOptions>
      Parameters:
      timeLimit - The actual time limit of the recorded video.
      Returns:
      self instance for chaining.
    • build

      public Map<String,Object> build()
      Description copied from class: BaseScreenRecordingOptions
      Builds a map, which is ready to be passed to the subordinated Appium API.
      Overrides:
      build in class BaseStartScreenRecordingOptions<WindowsStartScreenRecordingOptions>
      Returns:
      arguments mapping.