Class WindowsOptions
java.lang.Object
org.openqa.selenium.MutableCapabilities
io.appium.java_client.remote.options.BaseOptions<WindowsOptions>
io.appium.java_client.windows.options.WindowsOptions
- All Implemented Interfaces:
CanSetCapability<WindowsOptions>,SupportsAppOption<WindowsOptions>,SupportsAutomationNameOption<WindowsOptions>,SupportsBrowserNameOption<WindowsOptions>,SupportsEventTimingsOption<WindowsOptions>,SupportsFullResetOption<WindowsOptions>,SupportsNewCommandTimeoutOption<WindowsOptions>,SupportsNoResetOption<WindowsOptions>,SupportsPlatformVersionOption<WindowsOptions>,SupportsPostrunOption<WindowsOptions,,PowerShellData> SupportsPrerunOption<WindowsOptions,,PowerShellData> SupportsPrintPageSourceOnFindFailureOption<WindowsOptions>,SupportsWebSocketUrlOption<WindowsOptions>,SupportsAppArgumentsOption<WindowsOptions>,SupportsAppTopLevelWindowOption<WindowsOptions>,SupportsAppWorkingDirOption<WindowsOptions>,SupportsCreateSessionTimeoutOption<WindowsOptions>,SupportsMsExperimentalWebDriverOption<WindowsOptions>,SupportsMsWaitForAppLaunchOption<WindowsOptions>,SupportsSystemPortOption<WindowsOptions>,Serializable,org.openqa.selenium.Capabilities
public class WindowsOptions
extends BaseOptions<WindowsOptions>
implements SupportsAppOption<WindowsOptions>, SupportsAppArgumentsOption<WindowsOptions>, SupportsAppTopLevelWindowOption<WindowsOptions>, SupportsAppWorkingDirOption<WindowsOptions>, SupportsCreateSessionTimeoutOption<WindowsOptions>, SupportsMsWaitForAppLaunchOption<WindowsOptions>, SupportsMsExperimentalWebDriverOption<WindowsOptions>, SupportsSystemPortOption<WindowsOptions>, SupportsPrerunOption<WindowsOptions,PowerShellData>, SupportsPostrunOption<WindowsOptions,PowerShellData>
- See Also:
-
Field Summary
Fields inherited from interface io.appium.java_client.windows.options.SupportsAppArgumentsOption
APP_ARGUMENTS_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsAppOption
APP_OPTIONFields inherited from interface io.appium.java_client.windows.options.SupportsAppTopLevelWindowOption
APP_TOP_LEVEL_WINDOW_OPTIONFields inherited from interface io.appium.java_client.windows.options.SupportsAppWorkingDirOption
APP_WORKING_DIR_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsAutomationNameOption
AUTOMATION_NAME_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsBrowserNameOption
BROWSER_NAME_OPTIONFields inherited from interface io.appium.java_client.windows.options.SupportsCreateSessionTimeoutOption
CREATE_SESSION_TIMEOUT_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsEventTimingsOption
EVENT_TIMINGS_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsFullResetOption
FULL_RESET_OPTIONFields inherited from interface io.appium.java_client.windows.options.SupportsMsExperimentalWebDriverOption
MS_EXPERIMENTAL_WEBDRIVER_OPTIONFields inherited from interface io.appium.java_client.windows.options.SupportsMsWaitForAppLaunchOption
MS_WAIT_FOR_APP_LAUNCH_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsNewCommandTimeoutOption
NEW_COMMAND_TIMEOUT_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsNoResetOption
NO_RESET_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPlatformVersionOption
PLATFORM_VERSION_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPostrunOption
POSTRUN_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPrerunOption
PRERUN_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsPrintPageSourceOnFindFailureOption
PRINT_PAGE_SOURCE_ON_FIND_FAILURE_OPTIONFields inherited from interface io.appium.java_client.windows.options.SupportsSystemPortOption
SYSTEM_PORT_OPTIONFields inherited from interface io.appium.java_client.remote.options.SupportsWebSocketUrlOption
WEB_SOCKET_URL -
Constructor Summary
ConstructorsConstructorDescriptionWindowsOptions(Map<String, ?> source) WindowsOptions(org.openqa.selenium.Capabilities source) -
Method Summary
Modifier and TypeMethodDescriptionGet the postrun script.Get the prerun script.setPostrun(PowerShellData script) An object containing either script or command key.setPrerun(PowerShellData script) An object containing either script or command key.Methods inherited from class io.appium.java_client.remote.options.BaseOptions
asMap, clone, getCapability, getPlatformName, merge, setCapability, setPlatformName, toW3cNameMethods inherited from class org.openqa.selenium.MutableCapabilities
equals, getCapabilityNames, hashCode, setCapability, setCapability, setCapability, toJson, toStringMethods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, requiredMethods inherited from interface io.appium.java_client.windows.options.SupportsAppArgumentsOption
setAppArguments, setAppArgumentsMethods inherited from interface io.appium.java_client.remote.options.SupportsAppOption
getApp, setApp, setAppMethods inherited from interface io.appium.java_client.windows.options.SupportsAppTopLevelWindowOption
getAppTopLevelWindow, setAppTopLevelWindowMethods inherited from interface io.appium.java_client.windows.options.SupportsAppWorkingDirOption
getAppWorkingDir, setAppWorkingDirMethods inherited from interface io.appium.java_client.remote.options.SupportsAutomationNameOption
getAutomationName, setAutomationNameMethods inherited from interface io.appium.java_client.remote.options.SupportsBrowserNameOption
withBrowserNameMethods inherited from interface io.appium.java_client.windows.options.SupportsCreateSessionTimeoutOption
getCreateSessionTimeout, setCreateSessionTimeoutMethods inherited from interface io.appium.java_client.remote.options.SupportsEventTimingsOption
doesEventTimings, eventTimings, setEventTimingsMethods inherited from interface io.appium.java_client.remote.options.SupportsFullResetOption
doesFullReset, fullReset, setFullResetMethods inherited from interface io.appium.java_client.windows.options.SupportsMsExperimentalWebDriverOption
experimentalWebDriver, isExperimentalWebDriver, setExperimentalWebDriverMethods inherited from interface io.appium.java_client.windows.options.SupportsMsWaitForAppLaunchOption
doesWaitForAppLaunch, setWaitForAppLaunchMethods inherited from interface io.appium.java_client.remote.options.SupportsNewCommandTimeoutOption
getNewCommandTimeout, setNewCommandTimeoutMethods inherited from interface io.appium.java_client.remote.options.SupportsNoResetOption
doesNoReset, noReset, setNoResetMethods inherited from interface io.appium.java_client.remote.options.SupportsPlatformVersionOption
getPlatformVersion, setPlatformVersionMethods inherited from interface io.appium.java_client.remote.options.SupportsPrintPageSourceOnFindFailureOption
doesPrintPageSourceOnFindFailure, printPageSourceOnFindFailure, setPrintPageSourceOnFindFailureMethods inherited from interface io.appium.java_client.windows.options.SupportsSystemPortOption
getSystemPort, setSystemPortMethods inherited from interface io.appium.java_client.remote.options.SupportsWebSocketUrlOption
enableBiDi, getWebSocketUrl, setWebSocketUrl
-
Constructor Details
-
WindowsOptions
public WindowsOptions() -
WindowsOptions
public WindowsOptions(org.openqa.selenium.Capabilities source) -
WindowsOptions
-
-
Method Details
-
setPrerun
An object containing either script or command key. The value of each key must be a valid PowerShell script or command to be executed prior to the WinAppDriver session startup. See https://github.com/appium/appium-windows-driver#power-shell-commands-execution for more details.- Specified by:
setPrerunin interfaceSupportsPrerunOption<WindowsOptions,PowerShellData> - Parameters:
script- E.g. {script: 'Get-Process outlook -ErrorAction SilentlyContinue'}.- Returns:
- self instance for chaining.
-
getPrerun
Get the prerun script.- Specified by:
getPrerunin interfaceSupportsPrerunOption<WindowsOptions,PowerShellData> - Returns:
- Prerun script.
-
setPostrun
An object containing either script or command key. The value of each key must be a valid PowerShell script or command to be executed after an WinAppDriver session is finished. See https://github.com/appium/appium-windows-driver#power-shell-commands-execution for more details.- Specified by:
setPostrunin interfaceSupportsPostrunOption<WindowsOptions,PowerShellData> - Parameters:
script- E.g. {script: 'Get-Process outlook -ErrorAction SilentlyContinue'}.- Returns:
- self instance for chaining.
-
getPostrun
Get the postrun script.- Specified by:
getPostrunin interfaceSupportsPostrunOption<WindowsOptions,PowerShellData> - Returns:
- Postrun script.
-