Package io.appium.java_client
Class AppiumExecutionMethod
java.lang.Object
io.appium.java_client.AppiumExecutionMethod
- All Implemented Interfaces:
org.openqa.selenium.remote.ExecuteMethod
public class AppiumExecutionMethod
extends Object
implements org.openqa.selenium.remote.ExecuteMethod
-
Constructor Details
-
AppiumExecutionMethod
-
-
Method Details
-
execute
This method executes a command supported by Appium JSONWP.- Specified by:
executein interfaceorg.openqa.selenium.remote.ExecuteMethod- Parameters:
commandName- a JSONWP commandparameters- is a map which contains parameter names as keys and parameter values- Returns:
- a command execution result
-