Package io.appium.java_client
Class AppiumFluentWait.IterationInfo
java.lang.Object
io.appium.java_client.AppiumFluentWait.IterationInfo
- Enclosing class:
- AppiumFluentWait<T>
-
Constructor Summary
ConstructorsConstructorDescriptionIterationInfo(long number, Duration elapsed, Duration total, Duration interval) The class is used to represent information about a single loop iteration inAppiumFluentWait.until(Function)method. -
Method Summary
-
Constructor Details
-
IterationInfo
The class is used to represent information about a single loop iteration inAppiumFluentWait.until(Function)method.- Parameters:
number- loop iteration number, starts from 1elapsed- the amount of elapsed time since the loop startedtotal- the amount of total time to run the loopinterval- the default time interval for each loop iteration
-