Package io.appium.java_client
Interface HasAppStrings
- All Superinterfaces:
CanRememberExtensionPresence,ExecutesMethod
- All Known Implementing Classes:
AndroidDriver,FlutterAndroidDriver,FlutterIOSDriver,IOSDriver
-
Method Summary
Modifier and TypeMethodDescriptionGet all defined Strings from an app for the default language.getAppStringMap(String language) Get all defined Strings from an app for the specified language.getAppStringMap(String language, String stringFile) Get all defined Strings from an app for the specified language and strings filename.Methods inherited from interface io.appium.java_client.CanRememberExtensionPresence
assertExtensionExists, markExtensionAbsenceMethods inherited from interface io.appium.java_client.ExecutesMethod
execute, execute
-
Method Details
-
getAppStringMap
Get all defined Strings from an app for the default language. See the documentation for 'mobile: getAppStrings' extension for more details.- Returns:
- a map with localized strings defined in the app
-
getAppStringMap
Get all defined Strings from an app for the specified language. See the documentation for 'mobile: getAppStrings' extension for more details.- Parameters:
language- strings language code- Returns:
- a map with localized strings defined in the app
-
getAppStringMap
Get all defined Strings from an app for the specified language and strings filename. See the documentation for 'mobile: getAppStrings' extension for more details.- Parameters:
language- strings language codestringFile- strings filename. Ignored on Android- Returns:
- a map with localized strings defined in the app
-