Package io.appium.java_client
Interface HasBrowserCheck
- All Superinterfaces:
ExecutesMethod,org.openqa.selenium.HasCapabilities
- All Known Implementing Classes:
AndroidDriver,AppiumDriver,ChromiumDriver,FlutterAndroidDriver,FlutterIOSDriver,GeckoDriver,IOSDriver,Mac2Driver,SafariDriver,WindowsDriver
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptiondefault booleanValidates if the driver is currently in a web browser context.Methods inherited from interface io.appium.java_client.ExecutesMethod
execute, executeMethods inherited from interface org.openqa.selenium.HasCapabilities
getCapabilities
-
Field Details
-
NATIVE_CONTEXT
- See Also:
-
-
Method Details
-
isBrowser
default boolean isBrowser()Validates if the driver is currently in a web browser context.- Returns:
- true or false.
-