Package io.appium.java_client
Class MultiTouchAction
java.lang.Object
io.appium.java_client.MultiTouchAction
- All Implemented Interfaces:
PerformsActions<MultiTouchAction>
@Deprecated
public class MultiTouchAction
extends Object
implements PerformsActions<MultiTouchAction>
Deprecated.
Touch actions are deprecated.
Please use W3C Actions instead or the corresponding
extension methods for the driver (if available).
Check
- https://www.youtube.com/watch?v=oAJ7jwMNFVU
- https://appiumpro.com/editions/30-ios-specific-touch-action-methods
- https://appiumpro.com/editions/29-automating-complex-gestures-with-the-w3c-actions-api
for more details.
Used for Webdriver 3 multi-touch gestures
See the Webriver 3 spec https://dvcs.w3.org/hg/webdriver/raw-file/default/webdriver-spec.html
The MultiTouchAction object is a collection of TouchAction objects
(remember that TouchAction objects are in turn, a chain of individual actions)
Add multiple TouchAction objects using the add() method.
When perform() method is called, all actions are sent to the performsTouchActions.
The performsTouchActions performs the first step of each TouchAction object simultaneously as a multi-touch
"execution group". Conceptually, the number of TouchAction objects added to the MultiTouchAction
is equal to the number of "fingers" or other appendages or tools touching the screen at the
same time as part of this multi-gesture. Then the performsTouchActions performs the second step of each
TouchAction object and another "execution group", and the third, and so on.
Using a waitAction() action within a TouchAction takes up one of the slots in an
"execution group", so these can be used to sync up complex actions.
Calling perform() sends the action command to the Mobile Driver. Otherwise, more and
more actions can be chained.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionadd(TouchAction action) Deprecated.Add a TouchAction to this multi-touch gesture.protected MultiTouchActionDeprecated.Clears all the existing touch actions and resets the instance to the initial state.Deprecated.perform()Deprecated.Perform the multi-touch action on the mobile performsTouchActions.
-
Constructor Details
-
MultiTouchAction
Deprecated.
-
-
Method Details
-
add
Deprecated.Add a TouchAction to this multi-touch gesture.- Parameters:
action- TouchAction to add to this gesture- Returns:
- This MultiTouchAction, for chaining
-
perform
Deprecated.Perform the multi-touch action on the mobile performsTouchActions.- Specified by:
performin interfacePerformsActions<MultiTouchAction>
-
getParameters
Deprecated. -
clearActions
Deprecated.Clears all the existing touch actions and resets the instance to the initial state.- Returns:
- this MultiTouchAction, for possible segmented-touches.
-