Package io.appium.java_client
Interface PerformsTouchActions
- All Superinterfaces:
ExecutesMethod
- All Known Implementing Classes:
AndroidDriver,FlutterAndroidDriver,FlutterIOSDriver,IOSDriver,Mac2Driver,WindowsDriver
Deprecated.
Touch actions are deprecated.
Please use W3C Actions instead or the corresponding
extension methods for the driver (if available).
Check
- https://www.youtube.com/watch?v=oAJ7jwMNFVU
- https://appiumpro.com/editions/30-ios-specific-touch-action-methods
- https://appiumpro.com/editions/29-automating-complex-gestures-with-the-w3c-actions-api
for more details.
-
Method Summary
Modifier and TypeMethodDescriptiondefault MultiTouchActionperformMultiTouchAction(MultiTouchAction multiAction) Deprecated.default TouchActionperformTouchAction(TouchAction touchAction) Deprecated.Methods inherited from interface io.appium.java_client.ExecutesMethod
execute, execute
-
Method Details
-
performTouchAction
Deprecated.Performs a chain of touch actions, which together can be considered an entire gesture. See the Webriver 3 spec https://dvcs.w3.org/hg/webdriver/raw-file/default/webdriver-spec.html It's more convenient to call the perform() method of the TouchAction object itself. All the existing touch action parameters will be wiped out after this method is called.- Parameters:
touchAction- A TouchAction object, which contains a list of individual touch actions to perform- Returns:
- the same touch action object
-
performMultiTouchAction
Deprecated.Performs multiple TouchAction gestures at the same time, to simulate multiple fingers/touch inputs. See the Webriver 3 spec https://dvcs.w3.org/hg/webdriver/raw-file/default/webdriver-spec.html It's more convenient to call the perform() method of the MultiTouchAction object. All the existing multi touch actions will be wiped out after this method is called.- Parameters:
multiAction- the MultiTouchAction object to perform.- Returns:
- MultiTouchAction instance for chaining.
-