Package io.appium.java_client.android
Interface HasAndroidDeviceDetails
- All Superinterfaces:
CanRememberExtensionPresence,ExecutesMethod
- All Known Implementing Classes:
AndroidDriver,FlutterAndroidDriver
-
Method Summary
Modifier and TypeMethodDescriptiondefault LongRetrieve the display density of the Android device.Retrieve visibility and bounds information of the status and navigation bars.Methods inherited from interface io.appium.java_client.CanRememberExtensionPresence
assertExtensionExists, markExtensionAbsenceMethods inherited from interface io.appium.java_client.ExecutesMethod
execute, execute
-
Method Details
-
getDisplayDensity
Retrieve the display density of the Android device.- Returns:
- The density value in dpi
-
getSystemBars
Retrieve visibility and bounds information of the status and navigation bars.- Returns:
- The map where keys are bar types and values are mappings of bar properties.
-