Class AndroidInstallApplicationOptions
java.lang.Object
io.appium.java_client.appmanagement.BaseOptions<T>
io.appium.java_client.appmanagement.BaseInstallApplicationOptions<AndroidInstallApplicationOptions>
io.appium.java_client.android.appmanagement.AndroidInstallApplicationOptions
public class AndroidInstallApplicationOptions
extends BaseInstallApplicationOptions<AndroidInstallApplicationOptions>
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Creates a map based on the provided options.Disables a possibility to install packages marked as test in the manifest (the default setting).Allows to install packages marked as test in the manifest.Does not grant all the permissions requested in the application's manifest automatically after the installation is completed (the default behavior).Grants all the permissions requested in the application's manifest automatically after the installation is completed under Android 6+.Disables the possibility to upgrade/reinstall the application if it is already present on the device.Enables the possibility to upgrade/reinstall the application if it is already present on the device (the default behavior).withTimeout(Duration timeout) The time to wait until the app is installed (60000ms by default).Forces the application to be installed to the internal memory (the default behavior).Forces the application to be installed of SD card instead of the internal memory.
-
Constructor Details
-
AndroidInstallApplicationOptions
public AndroidInstallApplicationOptions()
-
-
Method Details
-
withReplaceEnabled
Enables the possibility to upgrade/reinstall the application if it is already present on the device (the default behavior).- Returns:
- self instance for chaining.
-
withReplaceDisabled
Disables the possibility to upgrade/reinstall the application if it is already present on the device.- Returns:
- self instance for chaining.
-
withTimeout
The time to wait until the app is installed (60000ms by default).- Parameters:
timeout- the actual timeout value. The minimum time resolution unit is one millisecond.- Returns:
- self instance for chaining.
-
withAllowTestPackagesEnabled
Allows to install packages marked as test in the manifest.- Returns:
- self instance for chaining.
-
withAllowTestPackagesDisabled
Disables a possibility to install packages marked as test in the manifest (the default setting).- Returns:
- self instance for chaining.
-
withUseSdcardEnabled
Forces the application to be installed of SD card instead of the internal memory.- Returns:
- self instance for chaining.
-
withUseSdcardDisabled
Forces the application to be installed to the internal memory (the default behavior).- Returns:
- self instance for chaining.
-
withGrantPermissionsEnabled
Grants all the permissions requested in the application's manifest automatically after the installation is completed under Android 6+.- Returns:
- self instance for chaining.
-
withGrantPermissionsDisabled
Does not grant all the permissions requested in the application's manifest automatically after the installation is completed (the default behavior).- Returns:
- self instance for chaining.
-
build
Description copied from class:BaseOptionsCreates a map based on the provided options.- Specified by:
buildin classBaseOptions<AndroidInstallApplicationOptions>- Returns:
- options mapping.
-