Enum Class AndroidKey
- All Implemented Interfaces:
Serializable,Comparable<AndroidKey>,Constable
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionKey code constant: 'A' key.Key code constant: Left Alt modifier key.Key code constant: Right Alt modifier key.Key code constant: ''' (apostrophe) key.Key code constant: App switch key.Key code constant: Assist key.Key code constant: '@' key.Key code constant: A/V Receiver input key.Key code constant: A/V Receiver power key.Key code constant: 'B' key.Key code constant: Back key.Key code constant: '\' key.Key code constant: Bookmark key.Key code constant: Break / Pause key.Key code constant: Brightness Down key.Key code constant: Brightness Up key.Key code constant: Generic Game Pad Button #1.Key code constant: Generic Game Pad Button #10.Key code constant: Generic Game Pad Button #11.Key code constant: Generic Game Pad Button #12.Key code constant: Generic Game Pad Button #13.Key code constant: Generic Game Pad Button #14.Key code constant: Generic Game Pad Button #15.Key code constant: Generic Game Pad Button #16.Key code constant: Generic Game Pad Button #2.Key code constant: Generic Game Pad Button #3.Key code constant: Generic Game Pad Button #4.Key code constant: Generic Game Pad Button #5.Key code constant: Generic Game Pad Button #6.Key code constant: Generic Game Pad Button #7.Key code constant: Generic Game Pad Button #8.Key code constant: Generic Game Pad Button #9.Key code constant: A Button key.Key code constant: B Button key.Key code constant: C Button key.Key code constant: L1 Button key.Key code constant: L2 Button key.Key code constant: Mode Button key.Key code constant: R1 Button key.Key code constant: R2 Button key.Key code constant: Select Button key.Key code constant: Start Button key.Key code constant: Left Thumb Button key.Key code constant: Right Thumb Button key.Key code constant: X Button key.Key code constant: Y Button key.Key code constant: Z Button key.Key code constant: 'C' key.Key code constant: Calculator special function key.Key code constant: Calendar special function key.Key code constant: Call key.Key code constant: Camera key.Key code constant: Caps Lock key.Key code constant: Toggle captions key.Key code constant: Channel down key.Key code constant: Channel up key.Key code constant: Clear key.Key code constant: ',' key.Key code constant: Contacts special function key.Key code constant: Copy key.Key code constant: Left Control modifier key.Key code constant: Right Control modifier key.Key code constant: Cut key.Key code constant: 'D' key.Key code constant: Backspace key.Key code constant: '0' key.Key code constant: '1' key.Key code constant: '2' key.Key code constant: '3' key.Key code constant: '4' key.Key code constant: '5' key.Key code constant: '6' key.Key code constant: '7' key.Key code constant: '8' key.Key code constant: '9' key.Key code constant: Directional Pad Center key.Key code constant: Directional Pad Down key.Key code constant: Directional Pad Down-Left.Key code constant: Directional Pad Down-Right.Key code constant: Directional Pad Left key.Key code constant: Directional Pad Right key.Key code constant: Directional Pad Up key.Key code constant: Directional Pad Up-Left.Key code constant: Directional Pad Up-Right.Key code constant: DVR key.Key code constant: 'E' key.Key code constant: Japanese alphanumeric key.Key code constant: End Call key.Key code constant: Enter key.Key code constant: Envelope special function key.Key code constant: '=' key.Key code constant: Escape key.Key code constant: Explorer special function key.Key code constant: 'F' key.Key code constant: F1 key.Key code constant: F10 key.Key code constant: F11 key.Key code constant: F12 key.Key code constant: F2 key.Key code constant: F3 key.Key code constant: F4 key.Key code constant: F5 key.Key code constant: F6 key.Key code constant: F7 key.Key code constant: F8 key.Key code constant: F9 key.Key code constant: Camera Focus key.Key code constant: Forward key.Key code constant: Forward Delete key.Key code constant: Function modifier key.Key code constant: 'G' key.Key code constant: '`' (backtick) key.Key code constant: Guide key.Key code constant: 'H' key.Key code constant: Headset Hook key.Key code constant: Help key.Key code constant: Japanese conversion key.Key code constant: Home key.Key code constant: 'I' key.Key code constant: Info key.Key code constant: Insert key.Key code constant: 'J' key.Key code constant: 'K' key.Key code constant: Japanese kana key.Key code constant: Japanese katakana / hiragana key.Key code constant: '11' key.Key code constant: '12' key.Key code constant: Zoom in key.Key code constant: Zoom out key.Key code constant: 'L' key.Key code constant: Language Switch key.Key code constant: Last Channel key.Key code constant: '[' key.Key code constant: 'M' key.Key code constant: Manner Mode key.Key code constant: Audio Track key.Key code constant: Close media key.Key code constant: Eject media key.Key code constant: Fast Forward media key.Key code constant: Play Next media key.Key code constant: Pause media key.Key code constant: Play media key.Key code constant: Play/Pause media key.Key code constant: Play Previous media key.Key code constant: Record media key.Key code constant: Rewind media key.Key code constant: Skip backward media key.Key code constant: Skip forward media key.Key code constant: Step backward media key.Key code constant: Step forward media key.Key code constant: Stop media key.Key code constant: Media Top Menu key.Key code constant: Menu key.Key code constant: Left Meta modifier key.Key code constant: Right Meta modifier key.Key code constant: '-'.Key code constant: 3D Mode key.Key code constant: End Movement key.Key code constant: Home Movement key.Key code constant: Japanese non-conversion key.Key code constant: Music special function key.Key code constant: Mute key.Key code constant: 'N' key.Key code constant: Navigate in key.Key code constant: Navigate to next key.Key code constant: Navigate out key.Key code constant: Navigate to previous key.Key code constant: Notification key.Key code constant: Number modifier key.Key code constant: Num Lock key.Key code constant: Numeric keypad '0' key.Key code constant: Numeric keypad '1' key.Key code constant: Numeric keypad '2' key.Key code constant: Numeric keypad '3' key.Key code constant: Numeric keypad '4' key.Key code constant: Numeric keypad '5' key.Key code constant: Numeric keypad '6' key.Key code constant: Numeric keypad '7' key.Key code constant: Numeric keypad '8' key.Key code constant: Numeric keypad '9' key.Key code constant: Numeric keypad '+' key (for addition).Key code constant: Numeric keypad ',' key (for decimals or digit grouping).Key code constant: Numeric keypad '/' key (for division).Key code constant: Numeric keypad '.' key (for decimals or digit grouping).Key code constant: Numeric keypad Enter key.Key code constant: Numeric keypad '=' key.Key code constant: Numeric keypad '(' key.Key code constant: Numeric keypad '*' key (for multiplication).Key code constant: Numeric keypad ')' key.Key code constant: Numeric keypad '-' key (for subtraction).Key code constant: 'O' key.Key code constant: 'P' key.Key code constant: Page Down key.Key code constant: Page Up key.Key code constant: Pairing key.Key code constant: Paste key.Key code constant: '.' key.Key code constant: Picture Symbols modifier key.Key code constant: '+' key.Key code constant: '#' key.Key code constant: Power key.Key code constant: Blue "programmable" key.Key code constant: Green "programmable" key.Key code constant: Red "programmable" key.Key code constant: Yellow "programmable" key.Key code constant: 'Q' key.Key code constant: 'R' key.Key code constant: ']' key.Key code constant: Japanese Ro key.Key code constant: 'S' key.Key code constant: Scroll Lock key.Key code constant: Search key.Key code constant: ';' key.Key code constant: Settings key.Key code constant: Left Shift modifier key.Key code constant: Right Shift modifier key.Key code constant: '/' key.Key code constant: Sleep key.Key code constant: Soft Left key.Key code constant: Soft Right key.Key code constant: put device to sleep unless a wakelock is held.Key code constant: Space key.Key code constant: '*' key.Key code constant: Set-top-box input key.Key code constant: Set-top-box power key.Key code constant: Generic stem key 1 for Wear.Key code constant: Generic stem key 2 for Wear.Key code constant: Generic stem key 3 for Wear.Key code constant: Primary stem key for Wear.Key code constant: Switch Charset modifier key.Key code constant: Symbol modifier key.Key code constant: System Request / Print Screen key.Key code constant: 'T' key.Key code constant: Tab key.Key code constant: TV key.Key code constant: Antenna/Cable key.Key code constant: Audio description key.Key code constant: Audio description mixing volume down key.Key code constant: Audio description mixing volume up key.Key code constant: Contents menu key.Key code constant: TV data service key.Key code constant: TV input key.Key code constant: Component #1 key.Key code constant: Component #2 key.Key code constant: Composite #1 key.Key code constant: Composite #2 key.Key code constant: HDMI #1 key.Key code constant: HDMI #2 key.Key code constant: HDMI #3 key.Key code constant: HDMI #4 key.Key code constant: VGA #1 key.Key code constant: Media context menu key.Key code constant: Toggle Network key.Key code constant: Number entry key.Key code constant: TV power key.Key code constant: Radio key.Key code constant: Satellite key.Key code constant: BS key.Key code constant: CS key.Key code constant: BS/CS key.Key code constant: Teletext key.Key code constant: Analog Terrestrial key.Key code constant: Digital Terrestrial key.Key code constant: Timer programming key.Key code constant: Zoom mode key.Key code constant: 'U' key.Key code constant: Unknown key code.Key code constant: 'V' key.Key code constant: Voice Assist key.Key code constant: Volume Down key.Key code constant: Volume Mute key.Key code constant: Volume Up key.Key code constant: 'W' key.Key code constant: Wakeup key.Key code constant: Window key.Key code constant: 'X' key.Key code constant: 'Y' key.Key code constant: Japanese Yen key.Key code constant: 'Z' key.Key code constant: Japanese full-width / half-width key. -
Method Summary
Modifier and TypeMethodDescriptionintgetCode()booleanWhether key will, by default, trigger a click on the focused view.booleanReturns true if the specified nativekey is a gamepad button.booleanWhether this key is a media key, which can be send to apps that are interested in media key events.booleanIs this a system key? System keys can not be used for menu shortcuts.booleanIs it wake key or not.static AndroidKeyReturns the enum constant of this class with the specified name.static AndroidKey[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
UNKNOWN
Key code constant: Unknown key code. -
SOFT_LEFT
Key code constant: Soft Left key. Usually situated below the display on phones and used as a multi-function feature key for selecting a software defined function shown on the bottom left of the display. -
SOFT_RIGHT
Key code constant: Soft Right key. Usually situated below the display on phones and used as a multi-function feature key for selecting a software defined function shown on the bottom right of the display. -
HOME
Key code constant: Home key. This key is handled by the framework and is never delivered to applications. -
BACK
Key code constant: Back key. -
CALL
Key code constant: Call key. -
ENDCALL
Key code constant: End Call key. -
DIGIT_0
Key code constant: '0' key. -
DIGIT_1
Key code constant: '1' key. -
DIGIT_2
Key code constant: '2' key. -
DIGIT_3
Key code constant: '3' key. -
DIGIT_4
Key code constant: '4' key. -
DIGIT_5
Key code constant: '5' key. -
DIGIT_6
Key code constant: '6' key. -
DIGIT_7
Key code constant: '7' key. -
DIGIT_8
Key code constant: '8' key. -
DIGIT_9
Key code constant: '9' key. -
STAR
Key code constant: '*' key. -
POUND
Key code constant: '#' key. -
DPAD_UP
Key code constant: Directional Pad Up key. May also be synthesized from trackball motions. -
DPAD_DOWN
Key code constant: Directional Pad Down key. May also be synthesized from trackball motions. -
DPAD_LEFT
Key code constant: Directional Pad Left key. May also be synthesized from trackball motions. -
DPAD_RIGHT
Key code constant: Directional Pad Right key. May also be synthesized from trackball motions. -
DPAD_CENTER
Key code constant: Directional Pad Center key. May also be synthesized from trackball motions. -
VOLUME_UP
Key code constant: Volume Up key. Adjusts the speaker volume up. -
VOLUME_DOWN
Key code constant: Volume Down key. Adjusts the speaker volume down. -
POWER
Key code constant: Power key. -
CAMERA
Key code constant: Camera key. Used to launch a camera application or take pictures. -
CLEAR
Key code constant: Clear key. -
A
Key code constant: 'A' key. -
B
Key code constant: 'B' key. -
C
Key code constant: 'C' key. -
D
Key code constant: 'D' key. -
E
Key code constant: 'E' key. -
F
Key code constant: 'F' key. -
G
Key code constant: 'G' key. -
H
Key code constant: 'H' key. -
I
Key code constant: 'I' key. -
J
Key code constant: 'J' key. -
K
Key code constant: 'K' key. -
L
Key code constant: 'L' key. -
M
Key code constant: 'M' key. -
N
Key code constant: 'N' key. -
O
Key code constant: 'O' key. -
P
Key code constant: 'P' key. -
Q
Key code constant: 'Q' key. -
R
Key code constant: 'R' key. -
S
Key code constant: 'S' key. -
T
Key code constant: 'T' key. -
U
Key code constant: 'U' key. -
V
Key code constant: 'V' key. -
W
Key code constant: 'W' key. -
X
Key code constant: 'X' key. -
Y
Key code constant: 'Y' key. -
Z
Key code constant: 'Z' key. -
COMMA
Key code constant: ',' key. -
PERIOD
Key code constant: '.' key. -
ALT_LEFT
Key code constant: Left Alt modifier key. -
ALT_RIGHT
Key code constant: Right Alt modifier key. -
SHIFT_LEFT
Key code constant: Left Shift modifier key. -
SHIFT_RIGHT
Key code constant: Right Shift modifier key. -
TAB
Key code constant: Tab key. -
SPACE
Key code constant: Space key. -
SYM
Key code constant: Symbol modifier key. Used to enter alternate symbols. -
EXPLORER
Key code constant: Explorer special function key. Used to launch a browser application. -
ENVELOPE
Key code constant: Envelope special function key. Used to launch a mail application. -
ENTER
Key code constant: Enter key. -
DEL
Key code constant: Backspace key. Deletes characters before the insertion point, unlikeFORWARD_DEL. -
GRAVE
Key code constant: '`' (backtick) key. -
MINUS
Key code constant: '-'. -
EQUALS
Key code constant: '=' key. -
LEFT_BRACKET
Key code constant: '[' key. -
RIGHT_BRACKET
Key code constant: ']' key. -
BACKSLASH
Key code constant: '\' key. -
SEMICOLON
Key code constant: ';' key. -
APOSTROPHE
Key code constant: ''' (apostrophe) key. -
SLASH
Key code constant: '/' key. -
AT
Key code constant: '@' key. -
NUM
Key code constant: Number modifier key. Used to enter numeric symbols. This key is not Num Lock; it is more likeALT_LEFTand is interpreted as an ALT key -
HEADSETHOOK
Key code constant: Headset Hook key. Used to hang up calls and stop media. -
FOCUS
Key code constant: Camera Focus key. Used to focus the camera. -
PLUS
Key code constant: '+' key. -
MENU
Key code constant: Menu key. -
NOTIFICATION
Key code constant: Notification key. -
SEARCH
Key code constant: Search key. -
MEDIA_PLAY_PAUSE
Key code constant: Play/Pause media key. -
MEDIA_STOP
Key code constant: Stop media key. -
MEDIA_NEXT
Key code constant: Play Next media key. -
MEDIA_PREVIOUS
Key code constant: Play Previous media key. -
MEDIA_REWIND
Key code constant: Rewind media key. -
MEDIA_FAST_FORWARD
Key code constant: Fast Forward media key. -
MUTE
Key code constant: Mute key. Mutes the microphone, unlikeVOLUME_MUTE. -
PAGE_UP
Key code constant: Page Up key. -
PAGE_DOWN
Key code constant: Page Down key. -
PICTSYMBOLS
Key code constant: Picture Symbols modifier key. Used to switch symbol sets (Emoji, Kao-moji). -
SWITCH_CHARSET
Key code constant: Switch Charset modifier key. Used to switch character sets (Kanji, Katakana). -
BUTTON_A
Key code constant: A Button key. On a game controller, the A button should be either the button labeled A or the first button on the bottom row of controller buttons. -
BUTTON_B
Key code constant: B Button key. On a game controller, the B button should be either the button labeled B or the second button on the bottom row of controller buttons. -
BUTTON_C
Key code constant: C Button key. On a game controller, the C button should be either the button labeled C or the third button on the bottom row of controller buttons. -
BUTTON_X
Key code constant: X Button key. On a game controller, the X button should be either the button labeled X or the first button on the upper row of controller buttons. -
BUTTON_Y
Key code constant: Y Button key. On a game controller, the Y button should be either the button labeled Y or the second button on the upper row of controller buttons. -
BUTTON_Z
Key code constant: Z Button key. On a game controller, the Z button should be either the button labeled Z or the third button on the upper row of controller buttons. -
BUTTON_L1
Key code constant: L1 Button key. On a game controller, the L1 button should be either the button labeled L1 (or L) or the top left trigger button. -
BUTTON_R1
Key code constant: R1 Button key. On a game controller, the R1 button should be either the button labeled R1 (or R) or the top right trigger button. -
BUTTON_L2
Key code constant: L2 Button key. On a game controller, the L2 button should be either the button labeled L2 or the bottom left trigger button. -
BUTTON_R2
Key code constant: R2 Button key. On a game controller, the R2 button should be either the button labeled R2 or the bottom right trigger button. -
BUTTON_THUMBL
Key code constant: Left Thumb Button key. On a game controller, the left thumb button indicates that the left (or only) joystick is pressed. -
BUTTON_THUMBR
Key code constant: Right Thumb Button key. On a game controller, the right thumb button indicates that the right joystick is pressed. -
BUTTON_START
Key code constant: Start Button key. On a game controller, the button labeled Start. -
BUTTON_SELECT
Key code constant: Select Button key. On a game controller, the button labeled Select. -
BUTTON_MODE
Key code constant: Mode Button key. On a game controller, the button labeled Mode. -
ESCAPE
Key code constant: Escape key. -
FORWARD_DEL
Key code constant: Forward Delete key. Deletes characters ahead of the insertion point, unlikeDEL. -
CTRL_LEFT
Key code constant: Left Control modifier key. -
CTRL_RIGHT
Key code constant: Right Control modifier key. -
CAPS_LOCK
Key code constant: Caps Lock key. -
SCROLL_LOCK
Key code constant: Scroll Lock key. -
META_LEFT
Key code constant: Left Meta modifier key. -
META_RIGHT
Key code constant: Right Meta modifier key. -
FUNCTION
Key code constant: Function modifier key. -
SYSRQ
Key code constant: System Request / Print Screen key. -
BREAK
Key code constant: Break / Pause key. -
MOVE_HOME
Key code constant: Home Movement key. Used for scrolling or moving the cursor around to the start of a line or to the top of a list. -
MOVE_END
Key code constant: End Movement key. Used for scrolling or moving the cursor around to the end of a line or to the bottom of a list. -
INSERT
Key code constant: Insert key. Toggles insert / overwrite edit mode. -
FORWARD
Key code constant: Forward key. Navigates forward in the history stack. Complement ofBACK. -
MEDIA_PLAY
Key code constant: Play media key. -
MEDIA_PAUSE
Key code constant: Pause media key. -
MEDIA_CLOSE
Key code constant: Close media key. May be used to close a CD tray, for example. -
MEDIA_EJECT
Key code constant: Eject media key. May be used to eject a CD tray, for example. -
MEDIA_RECORD
Key code constant: Record media key. -
F1
Key code constant: F1 key. -
F2
Key code constant: F2 key. -
F3
Key code constant: F3 key. -
F4
Key code constant: F4 key. -
F5
Key code constant: F5 key. -
F6
Key code constant: F6 key. -
F7
Key code constant: F7 key. -
F8
Key code constant: F8 key. -
F9
Key code constant: F9 key. -
F10
Key code constant: F10 key. -
F11
Key code constant: F11 key. -
F12
Key code constant: F12 key. -
NUM_LOCK
Key code constant: Num Lock key. This is the Num Lock key; it is different fromNUM. This key alters the behavior of other keys on the numeric keypad. -
NUMPAD_0
Key code constant: Numeric keypad '0' key. -
NUMPAD_1
Key code constant: Numeric keypad '1' key. -
NUMPAD_2
Key code constant: Numeric keypad '2' key. -
NUMPAD_3
Key code constant: Numeric keypad '3' key. -
NUMPAD_4
Key code constant: Numeric keypad '4' key. -
NUMPAD_5
Key code constant: Numeric keypad '5' key. -
NUMPAD_6
Key code constant: Numeric keypad '6' key. -
NUMPAD_7
Key code constant: Numeric keypad '7' key. -
NUMPAD_8
Key code constant: Numeric keypad '8' key. -
NUMPAD_9
Key code constant: Numeric keypad '9' key. -
NUMPAD_DIVIDE
Key code constant: Numeric keypad '/' key (for division). -
NUMPAD_MULTIPLY
Key code constant: Numeric keypad '*' key (for multiplication). -
NUMPAD_SUBTRACT
Key code constant: Numeric keypad '-' key (for subtraction). -
NUMPAD_ADD
Key code constant: Numeric keypad '+' key (for addition). -
NUMPAD_DOT
Key code constant: Numeric keypad '.' key (for decimals or digit grouping). -
NUMPAD_COMMA
Key code constant: Numeric keypad ',' key (for decimals or digit grouping). -
NUMPAD_ENTER
Key code constant: Numeric keypad Enter key. -
NUMPAD_EQUALS
Key code constant: Numeric keypad '=' key. -
NUMPAD_LEFT_PAREN
Key code constant: Numeric keypad '(' key. -
NUMPAD_RIGHT_PAREN
Key code constant: Numeric keypad ')' key. -
VOLUME_MUTE
Key code constant: Volume Mute key. Mutes the speaker, unlikeMUTE. This key should normally be implemented as a toggle such that the first press mutes the speaker and the second press restores the original volume. -
INFO
Key code constant: Info key. Common on TV remotes to show additional information related to what is currently being viewed. -
CHANNEL_UP
Key code constant: Channel up key. On TV remotes, increments the television channel. -
CHANNEL_DOWN
Key code constant: Channel down key. On TV remotes, decrements the television channel. -
KEYCODE_ZOOM_IN
Key code constant: Zoom in key. -
KEYCODE_ZOOM_OUT
Key code constant: Zoom out key. -
TV
Key code constant: TV key. On TV remotes, switches to viewing live TV. -
WINDOW
Key code constant: Window key. On TV remotes, toggles picture-in-picture mode or other windowing functions. -
GUIDE
Key code constant: Guide key. On TV remotes, shows a programming guide. -
DVR
Key code constant: DVR key. On some TV remotes, switches to a DVR mode for recorded shows. -
BOOKMARK
Key code constant: Bookmark key. On some TV remotes, bookmarks content or web pages. -
CAPTIONS
Key code constant: Toggle captions key. Switches the mode for closed-captioning text, for example during television shows. -
SETTINGS
Key code constant: Settings key. Starts the system settings activity. -
TV_POWER
Key code constant: TV power key. On TV remotes, toggles the power on a television screen. -
TV_INPUT
Key code constant: TV input key. On TV remotes, switches the input on a television screen. -
STB_POWER
Key code constant: Set-top-box power key. On TV remotes, toggles the power on an external Set-top-box. -
STB_INPUT
Key code constant: Set-top-box input key. On TV remotes, switches the input mode on an external Set-top-box. -
AVR_POWER
Key code constant: A/V Receiver power key. On TV remotes, toggles the power on an external A/V Receiver. -
AVR_INPUT
Key code constant: A/V Receiver input key. On TV remotes, switches the input mode on an external A/V Receiver. -
PROG_RED
Key code constant: Red "programmable" key. On TV remotes, acts as a contextual/programmable key. -
PROG_GREEN
Key code constant: Green "programmable" key. On TV remotes, actsas a contextual/programmable key. -
PROG_YELLOW
Key code constant: Yellow "programmable" key. On TV remotes, acts as a contextual/programmable key. -
PROG_BLUE
Key code constant: Blue "programmable" key. On TV remotes, acts as a contextual/programmable key. -
APP_SWITCH
Key code constant: App switch key. Should bring up the application switcher dialog. -
BUTTON_1
Key code constant: Generic Game Pad Button #1. -
BUTTON_2
Key code constant: Generic Game Pad Button #2. -
BUTTON_3
Key code constant: Generic Game Pad Button #3. -
BUTTON_4
Key code constant: Generic Game Pad Button #4. -
BUTTON_5
Key code constant: Generic Game Pad Button #5. -
BUTTON_6
Key code constant: Generic Game Pad Button #6. -
BUTTON_7
Key code constant: Generic Game Pad Button #7. -
BUTTON_8
Key code constant: Generic Game Pad Button #8. -
BUTTON_9
Key code constant: Generic Game Pad Button #9. -
BUTTON_10
Key code constant: Generic Game Pad Button #10. -
BUTTON_11
Key code constant: Generic Game Pad Button #11. -
BUTTON_12
Key code constant: Generic Game Pad Button #12. -
BUTTON_13
Key code constant: Generic Game Pad Button #13. -
BUTTON_14
Key code constant: Generic Game Pad Button #14. -
BUTTON_15
Key code constant: Generic Game Pad Button #15. -
BUTTON_16
Key code constant: Generic Game Pad Button #16. -
LANGUAGE_SWITCH
Key code constant: Language Switch key. Toggles the current input language such as switching between English and Japanese on a QWERTY keyboard. On some devices, the same function may be performed by pressing Shift+Spacebar. -
MANNER_MODE
Key code constant: Manner Mode key. Toggles silent or vibrate mode on and off to make the device behave more politely in certain settings such as on a crowded train. On some devices, the key may only operate when long-pressed. -
MODE_3D
Key code constant: 3D Mode key. Toggles the display between 2D and 3D mode. -
CONTACTS
Key code constant: Contacts special function key. Used to launch an address book application. -
CALENDAR
Key code constant: Calendar special function key. Used to launch a calendar application. -
MUSIC
Key code constant: Music special function key. Used to launch a music player application. -
CALCULATOR
Key code constant: Calculator special function key. Used to launch a calculator application. -
ZENKAKU_HANKAKU
Key code constant: Japanese full-width / half-width key. -
EISU
Key code constant: Japanese alphanumeric key. -
MUHENKAN
Key code constant: Japanese non-conversion key. -
HENKAN
Key code constant: Japanese conversion key. -
KATAKANA_HIRAGANA
Key code constant: Japanese katakana / hiragana key. -
YEN
Key code constant: Japanese Yen key. -
RO
Key code constant: Japanese Ro key. -
KANA
Key code constant: Japanese kana key. -
ASSIST
Key code constant: Assist key. Launches the global assist activity. Not delivered to applications. -
BRIGHTNESS_DOWN
Key code constant: Brightness Down key. Adjusts the screen brightness down. -
BRIGHTNESS_UP
Key code constant: Brightness Up key. Adjusts the screen brightness up. -
MEDIA_AUDIO_TRACK
Key code constant: Audio Track key. Switches the audio tracks. -
SLEEP
Key code constant: Sleep key. Puts the device to sleep. Behaves somewhat likePOWERbut it has no effect if the device is already asleep. -
WAKEUP
Key code constant: Wakeup key. Wakes up the device. Behaves somewhat likePOWERbut it has no effect if the device is already awake. -
PAIRING
Key code constant: Pairing key. Initiates peripheral pairing mode. Useful for pairing remote control devices or game controllers, especially if no other input mode is available. -
MEDIA_TOP_MENU
Key code constant: Media Top Menu key. Goes to the top of media menu. -
KEY_11
Key code constant: '11' key. -
KEY_12
Key code constant: '12' key. -
LAST_CHANNEL
Key code constant: Last Channel key. Goes to the last viewed channel. -
TV_DATA_SERVICE
Key code constant: TV data service key. Displays data services like weather, sports. -
VOICE_ASSIST
Key code constant: Voice Assist key. Launches the global voice assist activity. Not delivered to applications. -
TV_RADIO_SERVICE
Key code constant: Radio key. Toggles TV service / Radio service. -
TV_TELETEXT
Key code constant: Teletext key. Displays Teletext service. -
TV_NUMBER_ENTRY
Key code constant: Number entry key. Initiates to enter multi-digit channel nubmber when each digit key is assigned for selecting separate channel. Corresponds to Number Entry Mode (0x1D) of CEC User Control Code. -
TV_TERRESTRIAL_ANALOG
Key code constant: Analog Terrestrial key. Switches to analog terrestrial broadcast service. -
TV_TERRESTRIAL_DIGITAL
Key code constant: Digital Terrestrial key. Switches to digital terrestrial broadcast service. -
TV_SATELLITE
Key code constant: Satellite key. Switches to digital satellite broadcast service. -
TV_SATELLITE_BS
Key code constant: BS key. Switches to BS digital satellite broadcasting service available in Japan. -
TV_SATELLITE_CS
Key code constant: CS key. Switches to CS digital satellite broadcasting service available in Japan. -
TV_SATELLITE_SERVICE
Key code constant: BS/CS key. Toggles between BS and CS digital satellite services. -
TV_NETWORK
Key code constant: Toggle Network key. Toggles selecting broadcast services. -
TV_ANTENNA_CABLE
Key code constant: Antenna/Cable key. Toggles broadcast input source between antenna and cable. -
TV_INPUT_HDMI_1
Key code constant: HDMI #1 key. Switches to HDMI input #1. -
TV_INPUT_HDMI_2
Key code constant: HDMI #2 key. Switches to HDMI input #2. -
TV_INPUT_HDMI_3
Key code constant: HDMI #3 key. Switches to HDMI input #3. -
TV_INPUT_HDMI_4
Key code constant: HDMI #4 key. Switches to HDMI input #4. -
TV_INPUT_COMPOSITE_1
Key code constant: Composite #1 key. Switches to composite video input #1. -
TV_INPUT_COMPOSITE_2
Key code constant: Composite #2 key. Switches to composite video input #2. -
TV_INPUT_COMPONENT_1
Key code constant: Component #1 key. Switches to component video input #1. -
TV_INPUT_COMPONENT_2
Key code constant: Component #2 key. Switches to component video input #2. -
TV_INPUT_VGA_1
Key code constant: VGA #1 key. Switches to VGA (analog RGB) input #1. -
TV_AUDIO_DESCRIPTION
Key code constant: Audio description key. Toggles audio description off / on. -
TV_AUDIO_DESCRIPTION_MIX_UP
Key code constant: Audio description mixing volume up key. Louden audio description volume as compared with normal audio volume. -
TV_AUDIO_DESCRIPTION_MIX_DOWN
Key code constant: Audio description mixing volume down key. Lessen audio description volume as compared with normal audio volume. -
TV_ZOOM_MODE
Key code constant: Zoom mode key. Changes Zoom mode (Normal, Full, Zoom, Wide-zoom, etc.) -
TV_CONTENTS_MENU
Key code constant: Contents menu key. Goes to the title list. Corresponds to Contents Menu (0x0B) of CEC User Control Code -
TV_MEDIA_CONTEXT_MENU
Key code constant: Media context menu key. Goes to the context menu of media contents. Corresponds to Media Context-sensitive Menu (0x11) of CEC User Control Code. -
TV_TIMER_PROGRAMMING
Key code constant: Timer programming key. Goes to the timer recording menu. Corresponds to Timer Programming (0x54) of CEC User Control Code. -
HELP
Key code constant: Help key. -
NAVIGATE_PREVIOUS
Key code constant: Navigate to previous key. Goes backward by one item in an ordered collection of items. -
NAVIGATE_NEXT
Key code constant: Navigate to next key. Advances to the next item in an ordered collection of items. -
NAVIGATE_IN
Key code constant: Navigate in key. Activates the item that currently has focus or expands to the next level of a navigation hierarchy. -
NAVIGATE_OUT
Key code constant: Navigate out key. Backs out one level of a navigation hierarchy or collapses the item that currently has focus. -
STEM_PRIMARY
Key code constant: Primary stem key for Wear. Main power/reset button on watch. -
STEM_1
Key code constant: Generic stem key 1 for Wear. -
STEM_2
Key code constant: Generic stem key 2 for Wear. -
STEM_3
Key code constant: Generic stem key 3 for Wear. -
DPAD_UP_LEFT
Key code constant: Directional Pad Up-Left. -
DPAD_DOWN_LEFT
Key code constant: Directional Pad Down-Left. -
DPAD_UP_RIGHT
Key code constant: Directional Pad Up-Right. -
DPAD_DOWN_RIGHT
Key code constant: Directional Pad Down-Right. -
MEDIA_SKIP_FORWARD
Key code constant: Skip forward media key. -
MEDIA_SKIP_BACKWARD
Key code constant: Skip backward media key. -
MEDIA_STEP_FORWARD
Key code constant: Step forward media key. Steps media forward, one frame at a time. -
MEDIA_STEP_BACKWARD
Key code constant: Step backward media key. Steps media backward, one frame at a time. -
SOFT_SLEEP
Key code constant: put device to sleep unless a wakelock is held. -
CUT
Key code constant: Cut key. -
COPY
Key code constant: Copy key. -
PASTE
Key code constant: Paste key.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getCode
public int getCode() -
isGamepadButton
public boolean isGamepadButton()Returns true if the specified nativekey is a gamepad button.- Returns:
- True if the nativekey is a gamepad button, such as
BUTTON_A.
-
isConfirmKey
public boolean isConfirmKey()Whether key will, by default, trigger a click on the focused view.- Returns:
- true if this is a confirm key.
-
isMediaKey
public boolean isMediaKey()Whether this key is a media key, which can be send to apps that are interested in media key events.- Returns:
- true if this is a media key.
-
isSystemKey
public boolean isSystemKey()Is this a system key? System keys can not be used for menu shortcuts.- Returns:
- true if this is a system key.
-
isWakeKey
public boolean isWakeKey()Is it wake key or not.- Returns:
- true if this is a wakeup key.
-