Private flag that indicates when the system has detected that this key event
may be inconsistent with respect to the sequence of previously delivered key events,
such as when a key up event is sent but the key was not down.
This mask is set if an event was known to come from a trusted part
of the system. That is, the event is known to come from the user,
and could not have been spoofed by a third party component.
This mask is used for compatibility, to identify enter keys that are
coming from an IME whose enter key has been auto-labelled "next" or
"done". This allows TextView to dispatch these as normal enter keys
for old applications, but still do the appropriate action when
receiving them.
When associated with up key events, this indicates that the key press
has been canceled. Typically this is used with virtual touch screen
keys, where the user can slide from the virtual key area on to the
display: in that case, the application will receive a canceled up
event and should not perform the action normally associated with the
key. Note that for this to work, the application can not perform an
action for a key until it receives an up or the long press timeout has
expired.
This key event was generated by a virtual (on-screen) hard key area.
Typically this is an area of the touchscreen, outside of the regular
display, dedicated to "hardware" buttons.
Set for ACTION_UP when this event's key value is still being
tracked from its initial down. That is, somebody requested that tracking
started on the key down and a long press has not caused
the tracking to be canceled.
Set when a key event has been synthesized to implement default behavior
for an event that the application did not handle.
Fallback key events are generated by unhandled trackball motions
(to emulate a directional keypad) and by certain unhandled key presses
that are declared in the key map (such as special function numeric keypad
keys when numlock is off).
Private flag that indicates when the system has detected that this key event
may be inconsistent with respect to the sequence of previously delivered key events,
such as when a key up event is sent but the key was not down.
Returns the enum constant of this class with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this class. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.