Interface SupportsAndroidInstallTimeoutOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
EspressoOptions,UiAutomator2Options
public interface SupportsAndroidInstallTimeoutOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionGet maximum amount of time to wait until the application under test is installed.default TsetAndroidInstallTimeout(Duration installTimeout) Maximum amount of time to wait until the application under test is installed.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
ANDROID_INSTALL_TIMEOUT_OPTION
- See Also:
-
-
Method Details
-
setAndroidInstallTimeout
Maximum amount of time to wait until the application under test is installed. 90000 ms by default- Parameters:
installTimeout- App install timeout.- Returns:
- self instance for chaining.
-
getAndroidInstallTimeout
Get maximum amount of time to wait until the application under test is installed.- Returns:
- Timeout value.
-