Interface SupportsChromedriverUseSystemExecutableOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
EspressoOptions,UiAutomator2Options
public interface SupportsChromedriverUseSystemExecutableOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptiondefault TEnforce the usage of chromedriver, which gets downloaded by Appium automatically upon installation.Get whether to use the system chromedriver.default TsetChromedriverUseSystemExecutable(boolean value) Set it to true in order to enforce the usage of chromedriver, which gets downloaded by Appium automatically upon installation.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
CHROMEDRIVER_USE_SYSTEM_EXECUTABLE_OPTION
- See Also:
-
-
Method Details
-
chromedriverUseSystemExecutable
Enforce the usage of chromedriver, which gets downloaded by Appium automatically upon installation.- Returns:
- self instance for chaining.
-
setChromedriverUseSystemExecutable
Set it to true in order to enforce the usage of chromedriver, which gets downloaded by Appium automatically upon installation. This driver might not be compatible with the destination browser or a web view. false by default.- Parameters:
value- Whether to use the system chromedriver.- Returns:
- self instance for chaining.
-
doesChromedriverUseSystemExecutable
Get whether to use the system chromedriver.- Returns:
- True or false.
-