Interface SupportsLocaleScriptOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
EspressoOptions,UiAutomator2Options
public interface SupportsLocaleScriptOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionGet canonical name of the locale to be set for the app under test.default TsetLocaleScript(String localeScript) Set canonical name of the locale to be set for the app under test, for example zh-Hans-CN.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
LOCALE_SCRIPT_OPTION
- See Also:
-
-
Method Details
-
setLocaleScript
Set canonical name of the locale to be set for the app under test, for example zh-Hans-CN. See https://developer.android.com/reference/java/util/Locale.html for more details.- Parameters:
localeScript- is the language abbreviation.- Returns:
- this MobileOptions, for chaining.
-
getLocaleScript
Get canonical name of the locale to be set for the app under test.- Returns:
- Locale script value.
-