Interface SupportsDisableWindowAnimationOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
UiAutomator2Options
public interface SupportsDisableWindowAnimationOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptiondefault TDisables window animations when starting the instrumentation process.Get whether window animations when starting the instrumentation process are disabled.default TsetDisableWindowAnimation(boolean value) Set whether to disable window animations when starting the instrumentation process.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
DISABLE_WINDOWS_ANIMATION_OPTION
- See Also:
-
-
Method Details
-
disableWindowAnimation
Disables window animations when starting the instrumentation process.- Returns:
- self instance for chaining.
-
setDisableWindowAnimation
Set whether to disable window animations when starting the instrumentation process. false by default- Parameters:
value- True to disable window animations.- Returns:
- self instance for chaining.
-
doesDisableWindowAnimation
Get whether window animations when starting the instrumentation process are disabled.- Returns:
- True or false.
-