Interface SupportsUseSystemExecutableOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
ChromiumOptions
public interface SupportsUseSystemExecutableOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionGet the use system executable flag.default TsetUseSystemExecutable(boolean useSystemExecutable) Set to true to use the version of WebDriver bundled with this driver, rather than attempting to download a new one based on the version of the browser under test.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
USE_SYSTEM_EXECUTABLE
- See Also:
-
-
Method Details
-
setUseSystemExecutable
Set to true to use the version of WebDriver bundled with this driver, rather than attempting to download a new one based on the version of the browser under test. Unless disable build check preference has been user-set, the capability is not present because the default value is false.- Parameters:
useSystemExecutable- flag.- Returns:
- self instance for chaining.
-
isUseSystemExecutable
Get the use system executable flag.- Returns:
- use system executable flag.
-