Package io.appium.java_client.flutter
Interface FlutterIntegrationTestDriver
- All Superinterfaces:
CanExecuteFlutterScripts,org.openqa.selenium.JavascriptExecutor,org.openqa.selenium.SearchContext,SupportsFlutterCameraMocking,SupportsGestureOnFlutterElements,SupportsScrollingOfFlutterElements,SupportsWaitingForFlutterElements,org.openqa.selenium.WebDriver
- All Known Implementing Classes:
FlutterAndroidDriver,FlutterIOSDriver
public interface FlutterIntegrationTestDriver
extends org.openqa.selenium.WebDriver, SupportsGestureOnFlutterElements, SupportsScrollingOfFlutterElements, SupportsWaitingForFlutterElements, SupportsFlutterCameraMocking
The
FlutterDriver interface represents a driver that controls interactions with
Flutter applications, extending WebDriver and providing additional capabilities for
interacting with Flutter-specific elements and behaviors.
This interface serves as a common entity for drivers that support Flutter applications on different platforms, such as Android and iOS.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.openqa.selenium.WebDriver
org.openqa.selenium.WebDriver.Navigation, org.openqa.selenium.WebDriver.Options, org.openqa.selenium.WebDriver.TargetLocator, org.openqa.selenium.WebDriver.Timeouts, org.openqa.selenium.WebDriver.Window -
Method Summary
Methods inherited from interface io.appium.java_client.flutter.CanExecuteFlutterScripts
executeFlutterCommand, executeFlutterCommandMethods inherited from interface org.openqa.selenium.JavascriptExecutor
executeAsyncScript, executeScript, executeScript, getPinnedScripts, pin, unpinMethods inherited from interface io.appium.java_client.flutter.SupportsFlutterCameraMocking
activateInjectedImage, injectMockImage, injectMockImageMethods inherited from interface io.appium.java_client.flutter.SupportsGestureOnFlutterElements
performDoubleClick, performDragAndDrop, performLongPressMethods inherited from interface io.appium.java_client.flutter.SupportsScrollingOfFlutterElements
scrollTillVisibleMethods inherited from interface io.appium.java_client.flutter.SupportsWaitingForFlutterElements
waitForInVisible, waitForVisibleMethods inherited from interface org.openqa.selenium.WebDriver
close, findElement, findElements, get, getCurrentUrl, getPageSource, getTitle, getWindowHandle, getWindowHandles, manage, navigate, quit, switchTo