Class ScrollParameter
java.lang.Object
io.appium.java_client.flutter.commands.FlutterCommandParameter
io.appium.java_client.flutter.commands.ScrollParameter
-
Nested Class Summary
Nested Classes -
Constructor Summary
ConstructorsConstructorDescriptionScrollParameter(AppiumBy.FlutterBy scrollTo) Constructs a new ScrollOptions object with the given parameters.ScrollParameter(AppiumBy.FlutterBy scrollTo, ScrollParameter.ScrollDirection scrollDirection) Constructs a new ScrollOptions object with the given parameters. -
Method Summary
Methods inherited from class io.appium.java_client.flutter.commands.FlutterCommandParameter
parseFlutterLocator
-
Constructor Details
-
ScrollParameter
Constructs a new ScrollOptions object with the given parameters.- Parameters:
scrollTo- the locator used for scrolling to a specific element
-
ScrollParameter
public ScrollParameter(AppiumBy.FlutterBy scrollTo, ScrollParameter.ScrollDirection scrollDirection) Constructs a new ScrollOptions object with the given parameters.- Parameters:
scrollTo- the locator used for scrolling to a specific elementscrollDirection- the direction in which to scroll (e.g., ScrollDirection.DOWN)- Throws:
IllegalArgumentException- if scrollTo is null
-
-
Method Details
-
toJson
- Specified by:
toJsonin classFlutterCommandParameter
-