Interface SupportsFlutterElementWaitTimeoutOption<T extends BaseOptions<T>>
- All Superinterfaces:
CanSetCapability<T>,org.openqa.selenium.Capabilities,Serializable
- All Known Implementing Classes:
FlutterDriverOptions
public interface SupportsFlutterElementWaitTimeoutOption<T extends BaseOptions<T>>
extends org.openqa.selenium.Capabilities, CanSetCapability<T>
-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the current Flutter element wait timeout if set.default TsetFlutterElementWaitTimeout(Duration timeout) Sets the Flutter element wait timeout.Methods inherited from interface io.appium.java_client.remote.options.CanSetCapability
amend, setCapabilityMethods inherited from interface org.openqa.selenium.Capabilities
asMap, get, getBrowserName, getBrowserVersion, getCapability, getCapabilityNames, getPlatformName, is, merge, required
-
Field Details
-
FLUTTER_ELEMENT_WAIT_TIMEOUT_OPTION
- See Also:
-
-
Method Details
-
setFlutterElementWaitTimeout
Sets the Flutter element wait timeout. Defaults to 5 seconds.- Parameters:
timeout- The duration to wait for Flutter elements during findElement method- Returns:
- self instance for chaining.
-
getFlutterElementWaitTimeout
Retrieves the current Flutter element wait timeout if set.- Returns:
- An
Optionalcontaining the duration of the Flutter element wait timeout, or empty if not set.
-