Package io.appium.java_client.functions
Interface AppiumFunction<F,T>
- Type Parameters:
F- The input typeT- The return type
- All Superinterfaces:
com.google.common.base.Function<F,,T> Function<F,T>
- All Known Subinterfaces:
ExpectedCondition<T>
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@Deprecated
@FunctionalInterface
public interface AppiumFunction<F,T>
extends com.google.common.base.Function<F,T>, Function<F,T>
Deprecated.
This is extended version of
Function. It is combined
with Function. It was designed in order to provide compatibility
with the Wait.-
Method Summary
Modifier and TypeMethodDescriptiondefault <V> AppiumFunction<F,V> Deprecated.default <V> AppiumFunction<V,T> Deprecated.Methods inherited from interface com.google.common.base.Function
apply, equals
Functioninstead