Package io.appium.java_client.functions
Interface ExpectedCondition<T>
- Type Parameters:
T- The return type
- All Superinterfaces:
AppiumFunction<org.openqa.selenium.WebDriver,,T> org.openqa.selenium.support.ui.ExpectedCondition<T>,com.google.common.base.Function<org.openqa.selenium.WebDriver,,T> Function<org.openqa.selenium.WebDriver,T>
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@Deprecated
@FunctionalInterface
public interface ExpectedCondition<T>
extends org.openqa.selenium.support.ui.ExpectedCondition<T>, AppiumFunction<org.openqa.selenium.WebDriver,T>
Deprecated.
This is extended version of
ExpectedCondition. It is combined
with Function.-
Method Summary
Methods inherited from interface io.appium.java_client.functions.AppiumFunction
andThen, composeMethods inherited from interface com.google.common.base.Function
apply, equals
ExpectedConditioninstead