Class FeaturesMatchingOptions
java.lang.Object
io.appium.java_client.imagecomparison.BaseComparisonOptions<FeaturesMatchingOptions>
io.appium.java_client.imagecomparison.FeaturesMatchingOptions
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a map, which is ready to be passed to the subordinated Appium API.Sets the detector name for features matching algorithm.withGoodMatchesFactor(int factor) Sets the maximum count of "good" matches (e.Sets the name of the matching function.Methods inherited from class io.appium.java_client.imagecomparison.BaseComparisonOptions
withEnabledVisualization
-
Constructor Details
-
FeaturesMatchingOptions
public FeaturesMatchingOptions()
-
-
Method Details
-
withDetectorName
Sets the detector name for features matching algorithm. Some of these detectors (FAST, AGAST, GFTT, FAST, SIFT and MSER) are not available in the default OpenCV installation and have to be enabled manually before library compilation. The default detector name is 'ORB'.- Parameters:
name- the detector name for features matching.- Returns:
- self instance for chaining.
-
withMatchFunc
Sets the name of the matching function. The default one is 'BruteForce'.- Parameters:
name- the name of the matching function.- Returns:
- self instance for chaining.
-
withGoodMatchesFactor
Sets the maximum count of "good" matches (e. g. with minimal distances).- Parameters:
factor- the "good" matches factor- Returns:
- self instance for chaining.
-
build
Description copied from class:BaseComparisonOptionsBuilds a map, which is ready to be passed to the subordinated Appium API.- Overrides:
buildin classBaseComparisonOptions<FeaturesMatchingOptions>- Returns:
- comparison options mapping.
-