Package io.appium.java_client.internal
Class Config
java.lang.Object
io.appium.java_client.internal.Config
-
Method Summary
-
Method Details
-
main
Retrieve a facade for the main config.- Returns:
- interaction helper for 'main.properties' config
-
getValue
Retrieve a value from properties file.- Type Parameters:
T- the value type.- Parameters:
key- the name of the corresponding key which value to retrievevalueType- the expected type of the value to be retrieved- Returns:
- the actual value
- Throws:
IllegalArgumentException- if the given key does not existClassCastException- if the retrieved value cannot be cast to `valueType` type
-
getOptionalValue
Retrieve a value from properties file.- Type Parameters:
T- the type of the resulting value.- Parameters:
key- the name of the corresponding key which value to retrievevalueType- the expected type of the value to be retrieved- Returns:
- the actual value or
Optional.empty()if the key is not present - Throws:
UncheckedIOException- if the given properties file does not exist/not accessibleClassCastException- if the retrieved value cannot be cast to `valueType` type
-