Package io.appium.java_client.ios
Class IOSStartScreenRecordingOptions
java.lang.Object
io.appium.java_client.screenrecording.BaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T>>
io.appium.java_client.screenrecording.BaseStartScreenRecordingOptions<IOSStartScreenRecordingOptions>
io.appium.java_client.ios.IOSStartScreenRecordingOptions
public class IOSStartScreenRecordingOptions
extends BaseStartScreenRecordingOptions<IOSStartScreenRecordingOptions>
-
Nested Class Summary
Nested Classes -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a map, which is ready to be passed to the subordinated Appium API.withFps(int fps) The Frames Per Second rate of the recorded video.withTimeLimit(Duration timeLimit) The maximum recording time.withUploadOptions(ScreenRecordingUploadOptions uploadOptions) Upload options set for the recorded screen capture.withVideoFilters(String filters) The FFMPEG video filters to apply.withVideoQuality(IOSStartScreenRecordingOptions.VideoQuality videoQuality) The video encoding quality (low, medium, high, photo - defaults to medium).withVideoScale(String videoScale) The scaling value to apply.withVideoType(String videoType) The video codec type used for encoding of the recorded screen capture.Methods inherited from class io.appium.java_client.screenrecording.BaseStartScreenRecordingOptions
disableForcedRestart, enableForcedRestart
-
Constructor Details
-
IOSStartScreenRecordingOptions
public IOSStartScreenRecordingOptions()
-
-
Method Details
-
startScreenRecordingOptions
-
withUploadOptions
Upload options set for the recorded screen capture.- Overrides:
withUploadOptionsin classBaseScreenRecordingOptions<BaseStartScreenRecordingOptions<IOSStartScreenRecordingOptions>>- Parameters:
uploadOptions- see the documentation onScreenRecordingUploadOptionsfor more details.- Returns:
- self instance for chaining.
-
withVideoType
The video codec type used for encoding of the recorded screen capture. Execute `ffmpeg -codecs` in the terminal to see the list of supported video codecs. 'mjpeg' by default.- Parameters:
videoType- one of available video codec names, for example 'libx264'.- Returns:
- self instance for chaining.
- Since:
- Appium 1.10.0
-
withVideoQuality
public IOSStartScreenRecordingOptions withVideoQuality(IOSStartScreenRecordingOptions.VideoQuality videoQuality) The video encoding quality (low, medium, high, photo - defaults to medium). Only works for real devices.- Parameters:
videoQuality- one of possible quality preset names.- Returns:
- self instance for chaining.
-
withFps
The Frames Per Second rate of the recorded video. Defaults to 10.- Parameters:
fps- frames per second value in range 1..60.- Returns:
- self instance for chaining.
- Since:
- Appium 1.10.0
-
withVideoScale
The scaling value to apply. Read https://trac.ffmpeg.org/wiki/Scaling for possible values. No scale is applied by default. If filters are set then the scale setting is effectively ignored.- Parameters:
videoScale- ffmpeg-compatible scale format specifier.- Returns:
- self instance for chaining.
- Since:
- Appium 1.10.0
-
withTimeLimit
The maximum recording time. The default value is 180 seconds (3 minutes). The maximum value is 30 minutes. Setting values greater than this or less than zero will cause an exception. The minimum time resolution unit is one second.- Overrides:
withTimeLimitin classBaseStartScreenRecordingOptions<IOSStartScreenRecordingOptions>- Parameters:
timeLimit- The actual time limit of the recorded video.- Returns:
- self instance for chaining.
-
withVideoFilters
The FFMPEG video filters to apply. These filters allow to scale, flip, rotate and do many other useful transformations on the source video stream. The format of the property must comply with https://ffmpeg.org/ffmpeg-filters.html.- Parameters:
filters- One or more filters to apply to the resulting video stream, for example "transpose=1" to rotate the resulting video 90 degrees clockwise.- Returns:
- self instance for chaining.
- Since:
- Appium 1.15
-
build
Description copied from class:BaseScreenRecordingOptionsBuilds a map, which is ready to be passed to the subordinated Appium API.- Overrides:
buildin classBaseStartScreenRecordingOptions<IOSStartScreenRecordingOptions>- Returns:
- arguments mapping.
-