Annotation Interface AndroidBy
public @interface AndroidBy
Used to build a complex android automator locator.
-
Optional Element Summary
Optional ElementsModifier and TypeOptional ElementDescriptionIt an UI automation accessibility Id which is a convenient to Android.It is a className of the target element.It is an id of the target element.intPriority of the searching.It is a desired element tag.A String that can build an Android UiSelector or UiScrollable object.It is a xpath to the target element.
-
Element Details
-
uiAutomator
String uiAutomatorA String that can build an Android UiSelector or UiScrollable object. Refer to https://developer.android.com/training/testing/ui-automator- Returns:
- an Android UIAutomator string
- Default:
- ""
-
accessibility
String accessibilityIt an UI automation accessibility Id which is a convenient to Android. About Android accessibility https://developer.android.com/intl/ru/training/accessibility/accessible-app.html- Returns:
- an UI automation accessibility Id
- Default:
- ""
-
id
String idIt is an id of the target element.- Returns:
- an id of the target element
- Default:
- ""
-
className
String classNameIt is a className of the target element.- Returns:
- a className of the target element
- Default:
- ""
-
tagName
String tagNameIt is a desired element tag.- Returns:
- a desired element tag
- Default:
- ""
-
xpath
String xpathIt is a xpath to the target element.- Returns:
- a xpath to the target element
- Default:
- ""
-
priority
int priorityPriority of the searching. Higher number means lower priority.- Returns:
- priority of the searching
- Default:
- 0
-