Annotation Interface AndroidFindByAllSet
Defines set of chained/possible locators. Each one locator
should be defined with
AndroidFindAll-
Required Element Summary
Required ElementsModifier and TypeRequired ElementDescriptionAn array which builds a sequence of the chained searching for elements or a set of possible locators.
-
Element Details
-
value
AndroidFindAll[] valueAn array which builds a sequence of the chained searching for elements or a set of possible locators.- Returns:
- an array of
AndroidFindAllwhich builds a sequence of the chained searching for elements or a set of possible locators
-