Annotation Interface AndroidFindByChainSet
Defines set of chained/possible locators. Each one locator
should be defined with
AndroidFindBys-
Required Element Summary
Required ElementsModifier and TypeRequired ElementDescriptionAn array of which builds a sequence of the chained searching for elements or a set of possible locators.
-
Element Details
-
value
AndroidFindBys[] valueAn array of which builds a sequence of the chained searching for elements or a set of possible locators.- Returns:
- an array of
AndroidFindByswhich builds a sequence of the chained searching for elements or a set of possible locators
-