Annotation Interface AndroidFindBySet
Defines set of chained/possible locators. Each one locator
should be defined with
AndroidFindBy-
Required Element Summary
Required ElementsModifier and TypeRequired ElementDescriptionAn array of which builds a sequence of the chained searching for elements or a set of possible locators.
-
Element Details
-
value
AndroidFindBy[] valueAn array of which builds a sequence of the chained searching for elements or a set of possible locators.- Returns:
- an array of
AndroidFindBywhich builds a sequence of the chained searching for elements or a set of possible locators
-