The strategy which defines how to use locators which are described by the
AndroidFindBy annotation. These annotations can define the chained searching
or the searching by all possible locators.
Returns:
the strategy which defines how to use locators which are described by the
AndroidFindBy annotation
The strategy which defines how to use locators which are described by the
iOSXCUITFindBy annotation. These annotations can define the chained searching
or the searching by all possible locators.
Returns:
the strategy which defines how to use locators which are described by the
iOSXCUITFindBy annotation