Annotation Interface iOSBy
public @interface iOSBy
Used to build a complex iOS automation locator.
-
Optional Element Summary
Optional ElementsModifier and TypeOptional ElementDescriptionIt an UI automation accessibility Id which is a convenient to iOS.It is a name of a type/class of the target element.It is an id of the target element.intPriority of the searching.It is a desired element tag.It is an iOS UIAutomation string.It is a xpath to the target element.
-
Element Details
-
uiAutomator
String uiAutomatorIt is an iOS UIAutomation string. Read https://developer.apple.com/library/tvos/documentation/DeveloperTools/ Conceptual/InstrumentsUserGuide/UIAutomation.html- Returns:
- an iOS UIAutomation string
- Default:
- ""
-
accessibility
String accessibilityIt an UI automation accessibility Id which is a convenient to iOS. About iOS accessibility See UIAccessibilityIdentification- Returns:
- an UI automation accessibility Id
- Default:
- ""
-
id
String idIt is an id of the target element.- Returns:
- an id of the target element
- Default:
- ""
-
className
String classNameIt is a name of a type/class of the target element.- Returns:
- a name of a type/class of the target element
- Default:
- ""
-
tagName
String tagNameIt is a desired element tag.- Returns:
- a desired element tag
- Default:
- ""
-
xpath
String xpathIt is a xpath to the target element.- Returns:
- a xpath to the target element
- Default:
- ""
-
priority
int priorityPriority of the searching. Higher number means lower priority.- Returns:
- priority of the searching
- Default:
- 0
-