Annotation Interface iOSXCUITFindBySet
-
Required Element Summary
Required ElementsModifier and TypeRequired ElementDescriptionAn array of which builds a sequence of the chained searching for elements or a set of possible locators.
-
Element Details
-
value
iOSXCUITFindBy[] valueAn array of which builds a sequence of the chained searching for elements or a set of possible locators.- Returns:
- an array of
iOSXCUITFindBywhich builds a sequence of the chained searching for elements or a set of possible locators
-