Class StorageClient
java.lang.Object
io.appium.java_client.plugins.storage.StorageClient
This is a Java implementation of the Appium server storage plugin client.
See the plugin README
for more details.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionStorageClient(URL baseUrl) StorageClient(org.openqa.selenium.remote.http.ClientConfig clientConfig) -
Method Summary
-
Field Details
-
PREFIX
- See Also:
-
-
Constructor Details
-
StorageClient
-
StorageClient
public StorageClient(org.openqa.selenium.remote.http.ClientConfig clientConfig)
-
-
Method Details
-
add
Adds a local file to the server storage. The remote file name is be set to the same value as the local file name.- Parameters:
file- File instance.
-
add
Adds a local file to the server storage.- Parameters:
file- File instance.name- The remote file name.
-
list
Lists items that exist in the storage.- Returns:
- All storage items.
-
delete
Deletes an item from the server storage.- Parameters:
name- The name of the item to be deleted.- Returns:
- true if the dletion was successful.
-
reset
public void reset()Resets all items of the server storage.
-