Class StorageUtils
java.lang.Object
io.appium.java_client.plugins.storage.StorageUtils
-
Method Summary
Modifier and TypeMethodDescriptionstatic StringcalcSha1Digest(File source) Calculates SHA1 hex digest of the given file.static voidstreamFileToWebSocket(File source, org.openqa.selenium.remote.http.WebSocket socket) Feeds the content of the given file to the provided web socket.
-
Method Details
-
calcSha1Digest
Calculates SHA1 hex digest of the given file.- Parameters:
source- The file instance to calculate the hash for.- Returns:
- Hash digest represented as a string of hexadecimal numbers.
-
streamFileToWebSocket
public static void streamFileToWebSocket(File source, org.openqa.selenium.remote.http.WebSocket socket) Feeds the content of the given file to the provided web socket.- Parameters:
source- The source file instance.socket- The destination web socket.
-