Package io.appium.java_client.proxy
Class Interceptor
java.lang.Object
io.appium.java_client.proxy.Interceptor
-
Method Summary
-
Method Details
-
intercept
@RuntimeType public static Object intercept(@This Object self, @Origin Method method, @AllArguments Object[] args, @SuperCall Callable<?> callable) throws Throwable A magic method used to wrap public method calls in classes patched by ByteBuddy and acting as proxies. The performance of this method is mission-critical as it gets called upon every invocation of any method of the proxied class.- Parameters:
self- The reference to the original instance.method- The reference to the original method.args- The reference to method args.callable- The reference to the non-patched callable to avoid call recursion.- Returns:
- Either the original method result or the patched one.
- Throws:
Throwable
-