Package io.appium.java_client.remote
Class AppiumW3CHttpCommandCodec
java.lang.Object
org.openqa.selenium.remote.codec.AbstractHttpCommandCodec
org.openqa.selenium.remote.codec.w3c.W3CHttpCommandCodec
io.appium.java_client.remote.AppiumW3CHttpCommandCodec
- All Implemented Interfaces:
org.openqa.selenium.remote.CommandCodec<org.openqa.selenium.remote.http.HttpRequest>
public class AppiumW3CHttpCommandCodec
extends org.openqa.selenium.remote.codec.w3c.W3CHttpCommandCodec
-
Nested Class Summary
Nested classes/interfaces inherited from class org.openqa.selenium.remote.codec.AbstractHttpCommandCodec
org.openqa.selenium.remote.codec.AbstractHttpCommandCodec.CommandSpec -
Constructor Summary
ConstructorsConstructorDescriptionThis class overrides the built-in Selenium W3C commands codec, since the latter hardcodes many commands in Javascript, which does not work with Appium. -
Method Summary
Methods inherited from class org.openqa.selenium.remote.codec.AbstractHttpCommandCodec
decode, defineCommand, defineCommand, delete, encode, get, isSupported, post
-
Constructor Details
-
AppiumW3CHttpCommandCodec
public AppiumW3CHttpCommandCodec()This class overrides the built-in Selenium W3C commands codec, since the latter hardcodes many commands in Javascript, which does not work with Appium. Check https://www.w3.org/TR/webdriver/ to see all available W3C endpoints.
-
-
Method Details
-
alias
- Specified by:
aliasin interfaceorg.openqa.selenium.remote.CommandCodec<org.openqa.selenium.remote.http.HttpRequest>- Overrides:
aliasin classorg.openqa.selenium.remote.codec.AbstractHttpCommandCodec
-
amendParameters
- Overrides:
amendParametersin classorg.openqa.selenium.remote.codec.w3c.W3CHttpCommandCodec
-