Class BaseMapOptionData<T extends BaseMapOptionData<T>>
java.lang.Object
io.appium.java_client.remote.options.BaseMapOptionData<T>
- Direct Known Subclasses:
ActivityOptions,AppLocale,CommandTimeouts,EspressoBuildConfig,IntentOptions,Permissions,SystemScript,WebrtcData
-
Constructor Summary
ConstructorsConstructorDescriptionBaseMapOptionData(String json) BaseMapOptionData(Map<String, Object> options) -
Method Summary
Modifier and TypeMethodDescriptionassignOptionValue(String key, Object value) Sets the given value on the data object.<R> Optional<R>getOptionValue(String name) Retrieves a value with the given name from a data object.com.google.gson.JsonObjecttoJson()toMap()toString()
-
Constructor Details
-
BaseMapOptionData
public BaseMapOptionData() -
BaseMapOptionData
-
BaseMapOptionData
-
-
Method Details
-
assignOptionValue
Sets the given value on the data object.- Parameters:
key- Key name.value- The actual value to set.- Returns:
- self instance for chaining.
-
getOptionValue
Retrieves a value with the given name from a data object. This method does not perform any type transformation, but rather just tries to cast the received value to the given type, so be careful while providing a very specific result type value to not get a type cast error.- Type Parameters:
R- The expected value type.- Parameters:
name- Key name.- Returns:
- The actual value.
-
toMap
-
toJson
public com.google.gson.JsonObject toJson() -
toString
-