Class BaseStartScreenRecordingOptions<T extends BaseStartScreenRecordingOptions<T>>
java.lang.Object
io.appium.java_client.screenrecording.BaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T>>
io.appium.java_client.screenrecording.BaseStartScreenRecordingOptions<T>
- Direct Known Subclasses:
AndroidStartScreenRecordingOptions,IOSStartScreenRecordingOptions,Mac2StartScreenRecordingOptions,WindowsStartScreenRecordingOptions
public abstract class BaseStartScreenRecordingOptions<T extends BaseStartScreenRecordingOptions<T>>
extends BaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T>>
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Builds a map, which is ready to be passed to the subordinated Appium API.Whether to return silently if there is an active video recording.Whether to ignore the result of previous capture and start a new recording immediately.withTimeLimit(Duration timeLimit) The maximum recording time.Methods inherited from class io.appium.java_client.screenrecording.BaseScreenRecordingOptions
withUploadOptions
-
Constructor Details
-
BaseStartScreenRecordingOptions
public BaseStartScreenRecordingOptions()
-
-
Method Details
-
withTimeLimit
The maximum recording time.- Parameters:
timeLimit- The actual time limit of the recorded video.- Returns:
- self instance for chaining.
-
enableForcedRestart
Whether to ignore the result of previous capture and start a new recording immediately.- Returns:
- self instance for chaining.
-
disableForcedRestart
Whether to return silently if there is an active video recording.- Returns:
- self instance for chaining.
-
build
Description copied from class:BaseScreenRecordingOptionsBuilds a map, which is ready to be passed to the subordinated Appium API.- Overrides:
buildin classBaseScreenRecordingOptions<BaseStartScreenRecordingOptions<T extends BaseStartScreenRecordingOptions<T>>>- Returns:
- arguments mapping.
-