Enum Class AndroidServerFlag
- All Implemented Interfaces:
ServerArgument,Serializable,Comparable<AndroidServerFlag>,Constable
Here is the list of Android specific server arguments.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionPort to use on device to talk to Appium.ChromeDriver executable full path.Port upon which ChromeDriver will run.If set, prevents Appium from killing the adb server instance. -
Method Summary
Modifier and TypeMethodDescriptionstatic AndroidServerFlagReturns the enum constant of this class with the specified name.static AndroidServerFlag[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
BOOTSTRAP_PORT_NUMBER
Port to use on device to talk to Appium. Sample: --bootstrap-port 4724 -
SUPPRESS_ADB_KILL_SERVER
If set, prevents Appium from killing the adb server instance. Default: false -
CHROME_DRIVER_PORT
Port upon which ChromeDriver will run. Sample: --chromedriver-port 9515 -
CHROME_DRIVER_EXECUTABLE
ChromeDriver executable full path. -
REBOOT
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getArgument
- Specified by:
getArgumentin interfaceServerArgument
-