Class ElementOption
java.lang.Object
io.appium.java_client.touch.ActionOptions<T>
io.appium.java_client.touch.offset.PointOption<ElementOption>
io.appium.java_client.touch.offset.ElementOption
Deprecated.
-
Field Summary
Fields inherited from class io.appium.java_client.touch.offset.PointOption
coordinates -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Deprecated.Creates a map based on the provided options.static ElementOptionelement(org.openqa.selenium.WebElement element) Deprecated.This method creates a build instance of theElementOption.static ElementOptionelement(org.openqa.selenium.WebElement element, int x, int y) Deprecated.This method creates a build instance of theElementOption.static ElementOptionelement(org.openqa.selenium.WebElement element, org.openqa.selenium.Point offset) Deprecated.This method creates a build instance of theElementOption.protected voidverify()Deprecated.This method is automatically called before building options map to verify the consistency of the instance.withCoordinates(int xOffset, int yOffset) Deprecated.It defines x and y offset from the upper left corner of an element.withCoordinates(org.openqa.selenium.Point offset) Deprecated.It defines x and y offset from the upper left corner of an element.withElement(org.openqa.selenium.WebElement element) Deprecated.This method sets the element as an option.Methods inherited from class io.appium.java_client.touch.offset.PointOption
point, point
-
Constructor Details
-
ElementOption
public ElementOption()Deprecated.
-
-
Method Details
-
element
public static ElementOption element(org.openqa.selenium.WebElement element, org.openqa.selenium.Point offset) Deprecated.This method creates a build instance of theElementOption.- Parameters:
element- is the element to calculate offset from.offset- is the offset from the upper left corner of the given element.- Returns:
- the built option
-
element
Deprecated.This method creates a build instance of theElementOption.- Parameters:
element- is the element to calculate offset from.x- is the x-offset from the upper left corner of the given element.y- is the y-offset from the upper left corner of the given element.- Returns:
- the built option
-
element
Deprecated.This method creates a build instance of theElementOption.- Parameters:
element- is the element to calculate offset from.- Returns:
- the built option
-
withCoordinates
Deprecated.It defines x and y offset from the upper left corner of an element.- Overrides:
withCoordinatesin classPointOption<ElementOption>- Parameters:
offset- is the offset from the upper left corner of the given element.- Returns:
- self-reference
-
withCoordinates
Deprecated.It defines x and y offset from the upper left corner of an element.- Overrides:
withCoordinatesin classPointOption<ElementOption>- Parameters:
xOffset- is the x-offset from the upper left corner of the given element.yOffset- is the y-offset from the upper left corner of the given element.- Returns:
- self-reference
-
withElement
Deprecated.This method sets the element as an option. It means that x/y offset is the offset from the upper left corner of the given element.- Parameters:
element- is the element to calculate offset from.- Returns:
- self-reference
-
verify
protected void verify()Deprecated.Description copied from class:ActionOptionsThis method is automatically called before building options map to verify the consistency of the instance.- Overrides:
verifyin classPointOption<ElementOption>
-
build
Deprecated.Description copied from class:ActionOptionsCreates a map based on the provided options.- Overrides:
buildin classPointOption<ElementOption>- Returns:
- options mapping.
-