Class PointOption<T extends PointOption<T>>
java.lang.Object
io.appium.java_client.touch.ActionOptions<T>
io.appium.java_client.touch.offset.PointOption<T>
- Direct Known Subclasses:
ElementOption
Deprecated.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()Deprecated.Creates a map based on the provided options.static PointOptionpoint(int xOffset, int yOffset) Deprecated.It creates a built instance ofPointOptionwhich takes x and y coordinates.static PointOptionpoint(org.openqa.selenium.Point offset) Deprecated.It creates a built instance ofPointOptionwhich takes x and y coordinates.protected voidverify()Deprecated.This method is automatically called before building options map to verify the consistency of the instance.withCoordinates(int xOffset, int yOffset) Deprecated.It defines x and y coordinates.withCoordinates(org.openqa.selenium.Point offset) Deprecated.It defines x and y coordinates.
-
Field Details
-
coordinates
protected org.openqa.selenium.Point coordinatesDeprecated.
-
-
Constructor Details
-
PointOption
public PointOption()Deprecated.
-
-
Method Details
-
point
Deprecated.It creates a built instance ofPointOptionwhich takes x and y coordinates. This is offset from the upper left corner of the screen.- Parameters:
offset- is an offset value.- Returns:
- a built option
-
point
Deprecated.It creates a built instance ofPointOptionwhich takes x and y coordinates. This is offset from the upper left corner of the screen.- Parameters:
xOffset- is x value.yOffset- is y value.- Returns:
- a built option
-
withCoordinates
Deprecated.It defines x and y coordinates. This is offset from the upper left corner of the screen.- Parameters:
offset- is an offset value.- Returns:
- self-reference
-
withCoordinates
Deprecated.It defines x and y coordinates. This is offset from the upper left corner of the screen.- Parameters:
xOffset- is x value.yOffset- is y value.- Returns:
- self-reference
-
verify
protected void verify()Deprecated.Description copied from class:ActionOptionsThis method is automatically called before building options map to verify the consistency of the instance.- Specified by:
verifyin classActionOptions<T extends PointOption<T>>
-
build
Deprecated.Description copied from class:ActionOptionsCreates a map based on the provided options.- Overrides:
buildin classActionOptions<T extends PointOption<T>>- Returns:
- options mapping.
-